@@ -2,7 +2,7 @@
 Base tools for handling various kinds of data structures, attaching metadata to
 results, and doing data cleaning
 """
-from statsmodels.compat.python import iteritems, lmap
+from statsmodels.compat.python import lmap
 
 from functools import reduce
 
@@ -219,7 +219,7 @@ class ModelData(object):
         combined_2d = ()
         combined_2d_names = []
         if len(kwargs):
-            for key, value_array in iteritems(kwargs):
+            for key, value_array in kwargs.items():
                 if value_array is None or value_array.ndim == 0:
                     none_array_names += [key]
                     continue
@@ -592,7 +592,8 @@ class PandasData(ModelData):
         if squeezed.ndim < 2:
             return Series(squeezed, index=self.predict_dates)
         else:
-            return DataFrame(result, index=self.predict_dates,
+            return DataFrame(np.asarray(result),
+                             index=self.predict_dates,
                              columns=self.ynames)
 
     def attach_mv_confint(self, result):
