@@ -1,4 +1,5 @@
 """Stack loss data"""
+from statsmodels.datasets import utils as du
 
 __docformat__ = 'restructuredtext'
 
@@ -30,37 +31,36 @@ NOTE        = """::
         ACIDCONC  - Acid concentration of circulating acid minus 50 times 10.
 """
 
-from numpy import recfromtxt, column_stack, array
-from statsmodels.datasets import utils as du
-from os.path import dirname, abspath
 
-def load():
+def load(as_pandas=None):
     """
     Load the stack loss data and returns a Dataset class instance.
 
+    Parameters
+    ----------
+    as_pandas : bool
+        Flag indicating whether to return pandas DataFrames and Series
+        or numpy recarrays and arrays.  If True, returns pandas.
+
     Returns
-    --------
-    Dataset instance:
+    -------
+    Dataset
         See DATASET_PROPOSAL.txt for more information.
     """
-    data = _get_data()
-    return du.process_recarray(data, endog_idx=0, dtype=float)
+    return du.as_numpy_dataset(load_pandas(), as_pandas=as_pandas)
 
 def load_pandas():
     """
     Load the stack loss data and returns a Dataset class instance.
 
     Returns
-    --------
-    Dataset instance:
+    -------
+    Dataset
         See DATASET_PROPOSAL.txt for more information.
     """
     data = _get_data()
-    return du.process_recarray_pandas(data, endog_idx=0, dtype=float)
+    return du.process_pandas(data, endog_idx=0)
+
 
 def _get_data():
-    filepath = dirname(abspath(__file__))
-    with open(filepath + '/stackloss.csv',"rb") as f:
-        data = recfromtxt(f, delimiter=",",
-                          names=True, dtype=float)
-    return data
+    return du.load_csv(__file__, 'stackloss.csv').astype(float)
