@@ -62,7 +62,6 @@ class _OptFuncts(object):
     Any method starting with _ci_limits calculates the log likelihood
     ratio for a specific value of a parameter and then subtracts a
     pre-specified critical value.  This is solved so that llr - crit = 0.
-
     """
 
     def __init__(self, endog):
@@ -86,7 +85,7 @@ class _OptFuncts(object):
 
         Returns
         ------
-        data_star : array
+        data_star : ndarray
             The weighted logstar of the estimting equations
 
         Notes
@@ -286,7 +285,7 @@ class _OptFuncts(object):
             return chi2.sf(-2 * llr, 1)
         return -2 * llr
 
-    def  _ci_limits_var(self, var):
+    def _ci_limits_var(self, var):
         """
         Used to determine the confidence intervals for the variance.
         It calls test_var and when called by an optimizer,
@@ -375,7 +374,7 @@ class _OptFuncts(object):
         nuisance parameters mu and sigma
 
         Parameters
-        -----------
+        ----------
         nuis_params : 1darray
             An array with a nuisance mean and variance parameter
 
@@ -422,7 +421,7 @@ class _OptFuncts(object):
     def _ci_limits_kurt(self, kurt):
         """
         Parameters
-        ---------
+        ----------
         skew0 : float
             Hypothesized value of kurtosis
 
@@ -485,7 +484,7 @@ class DescStatUV(_OptFuncts):
 
     def __init__(self, endog):
         self.endog = np.squeeze(endog)
-        self.nobs = float(endog.shape[0])
+        self.nobs = endog.shape[0]
 
     def test_mean(self, mu0, return_weights=False):
         """
@@ -498,7 +497,7 @@ class DescStatUV(_OptFuncts):
             Mean value to be tested
 
         return_weights : bool
-            If return_weights is True the funtion returns
+            If return_weights is True the function returns
             the weights of the observations under the null hypothesis.
             Default is False
 
@@ -538,7 +537,7 @@ class DescStatUV(_OptFuncts):
             Lagrange (see Owen pg 22) and then determine the weights.
 
             'nested brent' uses brents method to find the confidence
-            intervals but must maximize the likelihhod ratio on every
+            intervals but must maximize the likelihood ratio on every
             iteration.
 
             gamma is generally much faster.  If the optimizations does not
@@ -565,7 +564,7 @@ class DescStatUV(_OptFuncts):
 
             When using 'gamma', amount to decrease (increase) the
             minimum (maximum) by to start the search for gamma.
-            If fucntion returns f(a) and f(b) must have differnt signs,
+            If function returns f(a) and f(b) must have different signs,
             consider lowering epsilon.
 
         Returns
@@ -584,7 +583,7 @@ class DescStatUV(_OptFuncts):
                 max(endog) - epsilon_u)
             llim = optimize.brentq(self._ci_limits_mu, middle,
                 min(endog) + epsilon_l)
-            return  llim, ulim
+            return llim, ulim
 
         if method == 'gamma':
             self.r0 = chi2.ppf(sig, 1)
@@ -602,7 +601,7 @@ class DescStatUV(_OptFuncts):
 
     def test_var(self, sig2_0, return_weights=False):
         """
-        Returns  -2 x log-likelihoog ratio and the p-value for the
+        Returns  -2 x log-likelihood ratio and the p-value for the
         hypothesized variance
 
         Parameters
@@ -615,12 +614,14 @@ class DescStatUV(_OptFuncts):
             likelihood of observing sig2_0. Default is False
 
         Returns
-        --------
+        -------
         test_results : tuple
             The  log-likelihood ratio and the p_value  of sig2_0
 
         Examples
         --------
+        >>> import numpy as np
+        >>> import statsmodels.api as sm
         >>> random_numbers = np.random.standard_normal(1000)*100
         >>> el_analysis = sm.emplike.DescStat(random_numbers)
         >>> hyp_test = el_analysis.test_var(9500)
@@ -634,7 +635,7 @@ class DescStatUV(_OptFuncts):
         if return_weights:
             return llr, p_val, self.new_weights.T
         else:
-            return  llr, p_val
+            return llr, p_val
 
     def ci_var(self, lower_bound=None, upper_bound=None, sig=.05):
         """
@@ -658,17 +659,20 @@ class DescStatUV(_OptFuncts):
             The significance level. Default is .05
 
         Returns
-        --------
+        -------
         Interval : tuple
             Confidence interval for the variance
 
         Examples
         --------
+        >>> import numpy as np
+        >>> import statsmodels.api as sm
         >>> random_numbers = np.random.standard_normal(100)
         >>> el_analysis = sm.emplike.DescStat(random_numbers)
         >>> el_analysis.ci_var()
-        >>> 'f(a) and f(b) must have different signs'
+        (0.7539322567470305, 1.229998852496268)
         >>> el_analysis.ci_var(.5, 2)
+        (0.7539322567469926, 1.2299988524962664)
 
         Notes
         -----
@@ -721,7 +725,7 @@ class DescStatUV(_OptFuncts):
 
         Returns
         -------
-        fig : matplotlib figure instance
+        Figure
             The contour plot
         """
         fig, ax = utils.create_mpl_ax()
@@ -753,7 +757,7 @@ class DescStatUV(_OptFuncts):
             maximize the likelihood ratio. Default is False.
 
         Returns
-        --------
+        -------
         test_results : tuple
             The log-likelihood ratio and p_value of skew0
         """
@@ -795,7 +799,7 @@ class DescStatUV(_OptFuncts):
                                      full_output=1, disp=0)[1]
         p_val = chi2.sf(llr, 1)
         if return_weights:
-            return  llr, p_val, self.new_weights.T
+            return llr, p_val, self.new_weights.T
         return llr, p_val
 
     def test_joint_skew_kurt(self, skew0, kurt0, return_weights=False):
@@ -873,7 +877,7 @@ class DescStatUV(_OptFuncts):
         self.r0 = chi2.ppf(1 - sig, 1)
         llim = optimize.brentq(self._ci_limits_skew, lower_bound, skew(endog))
         ulim = optimize.brentq(self._ci_limits_skew, skew(endog), upper_bound)
-        return   llim, ulim
+        return llim, ulim
 
     def ci_kurt(self, sig=.05, upper_bound=None, lower_bound=None):
         """
@@ -894,7 +898,7 @@ class DescStatUV(_OptFuncts):
             Default is .99 confidence limit assuming normality.
 
         Returns
-        --------
+        -------
         Interval : tuple
             Lower and upper confidence limit
 
@@ -928,7 +932,7 @@ class DescStatUV(_OptFuncts):
                              kurtosis(endog))
         ulim = optimize.brentq(self._ci_limits_kurt, kurtosis(endog), \
                              upper_bound)
-        return   llim, ulim
+        return llim, ulim
 
 
 class DescStatMV(_OptFuncts):
@@ -947,12 +951,11 @@ class DescStatMV(_OptFuncts):
 
     nobs : float
         Number of observations
-
     """
 
     def __init__(self, endog):
         self.endog = endog
-        self.nobs = float(endog.shape[0])
+        self.nobs = endog.shape[0]
 
     def mv_test_mean(self, mu_array, return_weights=False):
         """
@@ -977,13 +980,13 @@ class DescStatMV(_OptFuncts):
         endog = self.endog
         nobs = self.nobs
         if len(mu_array) != endog.shape[1]:
-            raise Exception('mu_array must have the same number of \
-                           elements as the columns of the data.')
+            raise ValueError('mu_array must have the same number of '
+                             'elements as the columns of the data.')
         mu_array = mu_array.reshape(1, endog.shape[1])
         means = np.ones((endog.shape[0], endog.shape[1]))
         means = mu_array * means
         est_vect = endog - means
-        start_vals = 1 / nobs * np.ones(endog.shape[1])
+        start_vals = 1. / nobs * np.ones(endog.shape[1])
         eta_star = self._modif_newton(start_vals, est_vect,
                                       np.ones(nobs) * (1. / nobs))
         denom = 1 + np.dot(eta_star, est_vect.T)
@@ -996,7 +999,7 @@ class DescStatMV(_OptFuncts):
             return llr, p_val
 
     def mv_mean_contour(self, mu1_low, mu1_upp, mu2_low, mu2_upp, step1, step2,
-                        levs=[.2, .1, .05, .01, .001], var1_name=None,
+                        levs=(.001, .01, .05, .1, .2), var1_name=None,
                         var2_name=None, plot_dta=False):
         """
         Creates a confidence region plot for the mean of bivariate data
@@ -1005,33 +1008,24 @@ class DescStatMV(_OptFuncts):
         ----------
         m1_low : float
             Minimum value of the mean for variable 1
-
         m1_upp : float
             Maximum value of the mean for variable 1
-
         mu2_low : float
             Minimum value of the mean for variable 2
-
         mu2_upp : float
             Maximum value of the mean for variable 2
-
         step1 : float
             Increment of evaluations for variable 1
-
         step2 : float
             Increment of evaluations for variable 2
-
         levs : list
             Levels to be drawn on the contour plot.
-            Default =  [.2, .1 .05, .01, .001]
-
+            Default =  (.001, .01, .05, .1, .2)
         plot_dta : bool
             If True, makes a scatter plot of the data on
             top of the contour plot. Defaultis False.
-
         var1_name : str
             Name of variable 1 to be plotted on the x-axis
-
         var2_name : str
             Name of variable 2 to be plotted on the y-axis
 
@@ -1045,13 +1039,14 @@ class DescStatMV(_OptFuncts):
 
         Examples
         --------
+        >>> import statsmodels.api as sm
         >>> two_rvs = np.random.standard_normal((20,2))
-        >>> el_analysis = sm.empllike.DescStat(two_rvs)
+        >>> el_analysis = sm.emplike.DescStat(two_rvs)
         >>> contourp = el_analysis.mv_mean_contour(-2, 2, -2, 2, .1, .1)
         >>> contourp.show()
         """
         if self.endog.shape[1] != 2:
-            raise Exception('Data must contain exactly two variables')
+            raise ValueError('Data must contain exactly two variables')
         fig, ax = utils.create_mpl_ax()
         if var2_name is None:
             ax.set_ylabel('Variable 2')
@@ -1061,8 +1056,8 @@ class DescStatMV(_OptFuncts):
             ax.set_xlabel('Variable 1')
         else:
             ax.set_xlabel(var1_name)
-        x = (np.arange(mu1_low, mu1_upp, step1))
-        y = (np.arange(mu2_low, mu2_upp, step2))
+        x = np.arange(mu1_low, mu1_upp, step1)
+        y = np.arange(mu2_low, mu2_upp, step2)
         pairs = itertools.product(x, y)
         z = []
         for i in pairs:
@@ -1092,7 +1087,7 @@ class DescStatMV(_OptFuncts):
         nobs = self.nobs
         endog = self.endog
         if endog.shape[1] != 2:
-            raise Exception('Correlation matrix not yet implemented')
+            raise NotImplementedError('Correlation matrix not yet implemented')
         nuis0 = np.array([endog[:, 0].mean(),
                               endog[:, 0].var(),
                               endog[:, 1].mean(),
@@ -1122,14 +1117,13 @@ class DescStatMV(_OptFuncts):
             Default is  99% confidence limit assuming normality.
 
         lower_bound : float
-            Minimum value the lower condidence limit can be.
+            Minimum value the lower confidence limit can be.
             Default is 99% confidence limit assuming normality.
 
         Returns
         -------
         interval : tuple
             Confidence interval for the correlation
-
         """
         endog = self.endog
         nobs = self.nobs
