@@ -6,7 +6,6 @@ Author: josef-pktd
 """
 
 
-from __future__ import print_function
 import numpy as np
 
 from scipy import special
@@ -51,7 +50,7 @@ class MyT(GenericLikelihoodModel):
 
         Parameters
         ----------
-        params : array-like
+        params : array_like
             The parameters of the model.
 
         Returns
