@@ -20,12 +20,12 @@ class Link(object):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Probabilities
 
         Returns
         -------
-        g(p) : array-like
+        g(p) : array_like
             The value of the link function g(p) = z
         """
         return NotImplementedError
@@ -36,16 +36,14 @@ class Link(object):
 
         Parameters
         ----------
-        z : array-like
+        z : array_like
             `z` is usually the linear predictor of the transformed variable
             in the IRLS algorithm for GLM.
 
         Returns
         -------
-        g^(-1)(z) : array
+        g^(-1)(z) : ndarray
             The value of the inverse of the link function g^(-1)(z) = p
-
-
         """
         return NotImplementedError
 
@@ -55,11 +53,11 @@ class Link(object):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
 
         Returns
         -------
-        g'(p) : array
+        g'(p) : ndarray
             The value of the derivative of the link function g'(p)
         """
         return NotImplementedError
@@ -77,24 +75,46 @@ class Link(object):
         """
         Derivative of the inverse link function g^(-1)(z).
 
-        Notes
-        -----
-        This reference implementation gives the correct result but is
-        inefficient, so it can be overriden in subclasses.
-
         Parameters
         ----------
-        z : array-like
+        z : array_like
             `z` is usually the linear predictor for a GLM or GEE model.
 
         Returns
         -------
-        g'^(-1)(z) : array
+        g'^(-1)(z) : ndarray
             The value of the derivative of the inverse of the link function
 
+        Notes
+        -----
+        This reference implementation gives the correct result but is
+        inefficient, so it can be overridden in subclasses.
         """
         return 1 / self.deriv(self.inverse(z))
 
+    def inverse_deriv2(self, z):
+        """
+        Second derivative of the inverse link function g^(-1)(z).
+
+        Parameters
+        ----------
+        z : array_like
+            `z` is usually the linear predictor for a GLM or GEE model.
+
+        Returns
+        -------
+        g'^(-1)(z) : ndarray
+            The value of the second derivative of the inverse of the link
+            function
+
+        Notes
+        -----
+        This reference implementation gives the correct result but is
+        inefficient, so it can be overridden in subclasses.
+        """
+        iz = self.inverse(z)
+        return -self.deriv2(iz) / self.deriv(iz)**3
+
 
 class Logit(Link):
     """
@@ -114,13 +134,13 @@ class Logit(Link):
         Clip logistic values to range (eps, 1-eps)
 
         Parameters
-        -----------
-        p : array-like
+        ----------
+        p : array_like
             Probabilities
 
         Returns
-        --------
-        pclip : array
+        -------
+        pclip : ndarray
             Clipped probabilities
         """
         return np.clip(p, FLOAT_EPS, 1. - FLOAT_EPS)
@@ -131,12 +151,12 @@ class Logit(Link):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Probabilities
 
         Returns
         -------
-        z : array
+        z : ndarray
             Logit transform of `p`
 
         Notes
@@ -152,12 +172,12 @@ class Logit(Link):
 
         Parameters
         ----------
-        z : array-like
+        z : array_like
             The value of the logit transform at `p`
 
         Returns
         -------
-        p : array
+        p : ndarray
             Probabilities
 
         Notes
@@ -169,18 +189,17 @@ class Logit(Link):
         return 1. / (1. + t)
 
     def deriv(self, p):
-
         """
         Derivative of the logit transform
 
         Parameters
         ----------
-        p: array-like
+        p : array_like
             Probabilities
 
         Returns
         -------
-        g'(p) : array
+        g'(p) : ndarray
             Value of the derivative of logit transform at `p`
 
         Notes
@@ -199,14 +218,13 @@ class Logit(Link):
 
         Parameters
         ----------
-        z : array-like
+        z : array_like
             `z` is usually the linear predictor for a GLM or GEE model.
 
         Returns
         -------
-        g'^(-1)(z) : array
+        g'^(-1)(z) : ndarray
             The value of the derivative of the inverse of the logit function
-
         """
         t = np.exp(z)
         return t/(1 + t)**2
@@ -217,12 +235,12 @@ class Logit(Link):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             probabilities
 
         Returns
         -------
-        g''(z) : array
+        g''(z) : ndarray
             The value of the second derivative of the logit function
         """
         v = p * (1 - p)
@@ -260,12 +278,12 @@ class Power(Link):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
         -------
-        z : array-like
+        z : array_like
             Power transform of x
 
         Notes
@@ -283,12 +301,12 @@ class Power(Link):
 
         Parameters
         ----------
-        `z` : array-like
+        `z` : array_like
             Value of the transformed mean parameters at `p`
 
         Returns
         -------
-        `p` : array
+        `p` : ndarray
             Mean parameters
 
         Notes
@@ -306,12 +324,12 @@ class Power(Link):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
-        --------
-        g'(p) : array
+        -------
+        g'(p) : ndarray
             Derivative of power transform of `p`
 
         Notes
@@ -329,12 +347,12 @@ class Power(Link):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
-        --------
-        g''(p) : array
+        -------
+        g''(p) : ndarray
             Second derivative of the power transform of `p`
 
         Notes
@@ -352,12 +370,12 @@ class Power(Link):
 
         Parameters
         ----------
-        z : array-like
+        z : array_like
             `z` is usually the linear predictor for a GLM or GEE model.
 
         Returns
         -------
-        g^(-1)'(z) : array
+        g^(-1)'(z) : ndarray
             The value of the derivative of the inverse of the power transform
         function
         """
@@ -366,6 +384,27 @@ class Power(Link):
         else:
             return np.power(z, (1 - self.power)/self.power) / self.power
 
+    def inverse_deriv2(self, z):
+        """
+        Second derivative of the inverse of the power transform
+
+        Parameters
+        ----------
+        z : array_like
+            `z` is usually the linear predictor for a GLM or GEE model.
+
+        Returns
+        -------
+        g^(-1)'(z) : ndarray
+            The value of the derivative of the inverse of the power transform
+        function
+        """
+        if self.power == 1:
+            return np.zeros_like(z)
+        else:
+            return ((1 - self.power) *
+                    np.power(z, (1 - 2*self.power)/self.power) / self.power**2)
+
 
 class inverse_power(Power):
     """
@@ -396,12 +435,12 @@ class sqrt(Power):
 
 
 class inverse_squared(Power):
-    """
+    r"""
     The inverse squared transform
 
     Notes
     -----
-    g(`p`) = 1/(`p`\ \*\*2)
+    g(`p`) = 1/(`p`\*\*2)
 
     Alias of statsmodels.family.links.Power(power=2.)
     """
@@ -442,12 +481,12 @@ class Log(Link):
 
         Parameters
         ----------
-        x : array-like
+        x : array_like
             Mean parameters
 
         Returns
         -------
-        z : array
+        z : ndarray
             log(x)
 
         Notes
@@ -463,12 +502,12 @@ class Log(Link):
 
         Parameters
         ----------
-        z : array
+        z : ndarray
             The inverse of the link function at `p`
 
         Returns
         -------
-        p : array
+        p : ndarray
             The mean probabilities given the value of the inverse `z`
 
         Notes
@@ -483,12 +522,12 @@ class Log(Link):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
         -------
-        g'(p) : array
+        g'(p) : ndarray
             derivative of log transform of x
 
         Notes
@@ -504,12 +543,12 @@ class Log(Link):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
         -------
-        g''(p) : array
+        g''(p) : ndarray
             Second derivative of log transform of x
 
         Notes
@@ -525,12 +564,12 @@ class Log(Link):
 
         Parameters
         ----------
-        z : array
+        z : ndarray
             The inverse of the link function at `p`
 
         Returns
         -------
-        g^(-1)'(z) : array
+        g^(-1)'(z) : ndarray
             The value of the derivative of the inverse of the log function,
             the exponential function
         """
@@ -575,12 +614,12 @@ class CDFLink(Logit):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
         -------
-        z : array
+        z : ndarray
             (ppf) inverse of CDF transform of p
 
         Notes
@@ -596,12 +635,12 @@ class CDFLink(Logit):
 
         Parameters
         ----------
-        z : array-like
+        z : array_like
             The value of the inverse of the link function at `p`
 
         Returns
         -------
-        p : array
+        p : ndarray
             Mean probabilities.  The value of the inverse of CDF link of `z`
 
         Notes
@@ -616,12 +655,12 @@ class CDFLink(Logit):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             mean parameters
 
         Returns
         -------
-        g'(p) : array
+        g'(p) : ndarray
             The derivative of CDF transform at `p`
 
         Notes
@@ -648,12 +687,12 @@ class CDFLink(Logit):
 
         Parameters
         ----------
-        z : array
+        z : ndarray
             The inverse of the link function at `p`
 
         Returns
         -------
-        g^(-1)'(z) : array
+        g^(-1)'(z) : ndarray
             The value of the derivative of the inverse of the logit function
         """
         return 1/self.deriv(self.inverse(z))
@@ -664,12 +703,29 @@ class probit(CDFLink):
     The probit (standard normal CDF) transform
 
     Notes
-    --------
+    -----
     g(p) = scipy.stats.norm.ppf(p)
 
     probit is an alias of CDFLink.
     """
-    pass
+
+    def inverse_deriv2(self, z):
+        """
+        Second derivative of the inverse link function
+
+        This is the derivative of the pdf in a CDFLink
+
+        """
+        return - z * self.dbn.pdf(z)
+
+    def deriv2(self, p):
+        """
+        Second derivative of the link function g''(p)
+
+        """
+        p = self._clean(p)
+        linpred = self.dbn.ppf(p)
+        return linpred / self.dbn.pdf(linpred)**2
 
 
 class cauchy(CDFLink):
@@ -692,18 +748,23 @@ class cauchy(CDFLink):
 
         Parameters
         ----------
-        p: array-like
+        p : array_like
             Probabilities
 
         Returns
         -------
-        g''(p) : array
+        g''(p) : ndarray
             Value of the second derivative of Cauchy link function at `p`
         """
+        p = self._clean(p)
         a = np.pi * (p - 0.5)
         d2 = 2 * np.pi**2 * np.sin(a) / np.cos(a)**3
         return d2
 
+    def inverse_deriv2(self, z):
+
+        return - 2 * z / (np.pi * (z**2 + 1)**2)
+
 
 class CLogLog(Logit):
     """
@@ -722,12 +783,12 @@ class CLogLog(Logit):
 
         Parameters
         ----------
-        p : array
+        p : ndarray
             Mean parameters
 
         Returns
         -------
-        z : array
+        z : ndarray
             The CLogLog transform of `p`
 
         Notes
@@ -744,12 +805,12 @@ class CLogLog(Logit):
 
         Parameters
         ----------
-        z : array-like
+        z : array_like
             The value of the inverse of the CLogLog link function at `p`
 
         Returns
         -------
-        p : array
+        p : ndarray
             Mean parameters
 
         Notes
@@ -764,12 +825,12 @@ class CLogLog(Logit):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
         -------
-        g'(p) : array
+        g'(p) : ndarray
             The derivative of the CLogLog transform link function
 
         Notes
@@ -785,12 +846,12 @@ class CLogLog(Logit):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
         -------
-        g''(p) : array
+        g''(p) : ndarray
             The second derivative of the CLogLog link function
         """
         p = self._clean(p)
@@ -805,12 +866,12 @@ class CLogLog(Logit):
 
         Parameters
         ----------
-        z : array-like
+        z : array_like
             The value of the inverse of the CLogLog link function at `p`
 
         Returns
         -------
-        g^(-1)'(z) : array
+        g^(-1)'(z) : ndarray
             The derivative of the inverse of the CLogLog link function
         """
         return np.exp(z - np.exp(z))
@@ -830,7 +891,7 @@ class cloglog(CLogLog):
     pass
 
 
-class NegativeBinomial(object):
+class NegativeBinomial(Link):
     '''
     The negative binomial link function
 
@@ -854,12 +915,12 @@ class NegativeBinomial(object):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
         -------
-        z : array
+        z : ndarray
             The negative binomial transform of `p`
 
         Notes
@@ -874,13 +935,13 @@ class NegativeBinomial(object):
         Inverse of the negative binomial transform
 
         Parameters
-        -----------
-        z : array-like
+        ----------
+        z : array_like
             The value of the inverse of the negative binomial link at `p`.
 
         Returns
         -------
-        p : array
+        p : ndarray
             Mean parameters
 
         Notes
@@ -895,12 +956,12 @@ class NegativeBinomial(object):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
         -------
-        g'(p) : array
+        g'(p) : ndarray
             The derivative of the negative binomial transform link function
 
         Notes
@@ -915,12 +976,12 @@ class NegativeBinomial(object):
 
         Parameters
         ----------
-        p : array-like
+        p : array_like
             Mean parameters
 
         Returns
         -------
-        g''(p) : array
+        g''(p) : ndarray
             The second derivative of the negative binomial transform link
             function
 
@@ -937,13 +998,13 @@ class NegativeBinomial(object):
         Derivative of the inverse of the negative binomial transform
 
         Parameters
-        -----------
-        z : array-like
+        ----------
+        z : array_like
             Usually the linear predictor for a GLM or GEE model
 
         Returns
         -------
-        g^(-1)'(z) : array
+        g^(-1)'(z) : ndarray
             The value of the derivative of the inverse of the negative
             binomial link
         '''
