@@ -73,9 +73,6 @@ def test_deriv2():
     np.random.seed(24235)
 
     for link in Links:
-        # TODO: Resolve errors with the numeric derivatives
-        if isinstance(link, links.probit):
-            continue
         for k in range(10):
             p = np.random.uniform(0, 1)
             p = np.clip(p, 0.01, 0.99)
@@ -83,7 +80,7 @@ def test_deriv2():
                 p = np.clip(p, 0.03, 0.97)
             d = link.deriv2(p)
             da = nd.approx_fprime(np.r_[p], link.deriv)
-            assert_allclose(d, da, rtol=1e-6, atol=1e-6,
+            assert_allclose(d, da, rtol=5e-6, atol=1e-6,
                             err_msg=str(link))
 
 
