@@ -10,7 +10,9 @@ update
 2011-10-27 : docstrings
 
 '''
-from statsmodels.compat.python import lrange, string_types, lzip, range
+from statsmodels.compat.python import lrange, lzip
+from statsmodels.compat.pandas import Appender
+
 import numpy as np
 import pandas as pd
 from patsy import dmatrix
@@ -22,12 +24,13 @@ from statsmodels.sandbox.regression.predstd import wls_prediction_std
 from statsmodels.graphics import utils
 from statsmodels.nonparametric.smoothers_lowess import lowess
 from statsmodels.tools.tools import maybe_unwrap_results
-from statsmodels.base import model
 
 from ._regressionplots_doc import (
     _plot_added_variable_doc,
     _plot_partial_residuals_doc,
-    _plot_ceres_residuals_doc)
+    _plot_ceres_residuals_doc,
+    _plot_influence_doc,
+    _plot_leverage_resid2_doc)
 
 __all__ = ['plot_fit', 'plot_regress_exog', 'plot_partregress', 'plot_ccpr',
            'plot_regress_exog', 'plot_partregress_grid', 'plot_ccpr_grid',
@@ -48,7 +51,7 @@ def add_lowess(ax, lines_idx=0, frac=.2, **lowess_kwargs):
 
     Parameters
     ----------
-    ax : matplotlib Axes instance
+    ax : AxesSubplot
         The Axes to which to add the plot
     lines_idx : int
         This is the line on the existing plot to which you want to add
@@ -60,7 +63,7 @@ def add_lowess(ax, lines_idx=0, frac=.2, **lowess_kwargs):
 
     Returns
     -------
-    fig : matplotlib Figure instance
+    Figure
         The figure that holds the instance.
     """
     y0 = ax.get_lines()[lines_idx]._y
@@ -70,30 +73,35 @@ def add_lowess(ax, lines_idx=0, frac=.2, **lowess_kwargs):
     return ax.figure
 
 
-def plot_fit(results, exog_idx, y_true=None, ax=None, **kwargs):
-    """Plot fit against one regressor.
+def plot_fit(results, exog_idx, y_true=None, ax=None, vlines=True, **kwargs):
+    """
+    Plot fit against one regressor.
 
-    This creates one graph with the scatterplot of observed values compared to
-    fitted values.
+    This creates one graph with the scatterplot of observed values
+    compared to fitted values.
 
     Parameters
     ----------
-    results : result instance
-        result instance with resid, model.endog and model.exog as attributes
-    x_var : int or str
+    results : Results
+        A result instance with resid, model.endog and model.exog as
+        attributes.
+    exog_idx : {int, str}
         Name or index of regressor in exog matrix.
-    y_true : array_like
-        (optional) If this is not None, then the array is added to the plot
-    ax : Matplotlib AxesSubplot instance, optional
+    y_true : array_like. optional
+        If this is not None, then the array is added to the plot.
+    ax : AxesSubplot, optional
         If given, this subplot is used to plot in instead of a new figure being
         created.
-    kwargs
+    vlines : bool, optional
+        If this not True, then the uncertainty of the fit is not
+        plotted.
+    **kwargs
         The keyword arguments are passed to the plot command for the fitted
         values points.
 
     Returns
     -------
-    fig : Matplotlib figure instance
+    Figure
         If `ax` is None, the created figure.  Otherwise the figure to which
         `ax` is connected.
 
@@ -125,7 +133,6 @@ def plot_fit(results, exog_idx, y_true=None, ax=None, **kwargs):
     >>> plt.show()
 
     .. plot:: plots/graphics_plot_fit_ex.py
-
     """
 
     fig, ax = utils.create_mpl_ax(ax)
@@ -141,15 +148,16 @@ def plot_fit(results, exog_idx, y_true=None, ax=None, **kwargs):
     x1 = x1[x1_argsort]
 
     ax.plot(x1, y, 'bo', label=results.model.endog_names)
-    if not y_true is None:
+    if y_true is not None:
         ax.plot(x1, y_true[x1_argsort], 'b-', label='True values')
     title = 'Fitted values versus %s' % exog_name
 
-    prstd, iv_l, iv_u = wls_prediction_std(results)
     ax.plot(x1, results.fittedvalues[x1_argsort], 'D', color='r',
             label='fitted', **kwargs)
-    ax.vlines(x1, iv_l[x1_argsort], iv_u[x1_argsort], linewidth=1, color='k',
-              alpha=.7)
+    if vlines is True:
+        _, iv_l, iv_u = wls_prediction_std(results)
+        ax.vlines(x1, iv_l[x1_argsort], iv_u[x1_argsort], linewidth=1,
+                  color='k', alpha=.7)
     #ax.fill_between(x1, iv_l[x1_argsort], iv_u[x1_argsort], alpha=0.1,
     #                    color='k')
     ax.set_title(title)
@@ -170,16 +178,41 @@ def plot_regress_exog(results, exog_idx, fig=None):
     Parameters
     ----------
     results : result instance
-        result instance with resid, model.endog and model.exog as attributes
-    exog_idx : int
-        index of regressor in exog matrix
-    fig : Matplotlib figure instance, optional
+        A result instance with resid, model.endog and model.exog as attributes.
+    exog_idx : int or str
+        Name or index of regressor in exog matrix.
+    fig : Figure, optional
         If given, this figure is simply returned.  Otherwise a new figure is
         created.
 
     Returns
     -------
-    fig : matplotlib figure instance
+    Figure
+        The value of `fig` if provided. Otherwise a new instance.
+
+    Examples
+    --------
+    Load the Statewide Crime data set and build a model with regressors
+    including the rate of high school graduation (hs_grad), population in urban
+    areas (urban), households below poverty line (poverty), and single person
+    households (single).  Outcome variable is the murder rate (murder).
+
+    Build a 2 by 2 figure based on poverty showing fitted versus actual murder
+    rate, residuals versus the poverty rate, partial regression plot of poverty,
+    and CCPR plot for poverty rate.
+
+    >>> import statsmodels.api as sm
+    >>> import matplotlib.pyplot as plot
+    >>> import statsmodels.formula.api as smf
+
+    >>> fig = plt.figure(figsize=(8, 6))
+    >>> crime_data = sm.datasets.statecrime.load_pandas()
+    >>> results = smf.ols('murder ~ hs_grad + urban + poverty + single',
+    ...                   data=crime_data.data).fit()
+    >>> sm.graphics.plot_regress_exog(results, 'poverty', fig=fig)
+    >>> plt.show()
+
+    .. plot:: plots/graphics_regression_regress_exog.py
     """
 
     fig = utils.create_mpl_fig(fig)
@@ -256,9 +289,8 @@ def _partial_regression(endog, exog_i, exog_others):
     (res1a, res1b) : tuple of OLS results instances
          results from regression of endog on exog_others and of exog_i on
          exog_others
-
     """
-    #FIXME: This function doesn't appear to be used.
+    #FIXME: This function does not appear to be used.
     res1a = OLS(endog, exog_others).fit()
     res1b = OLS(exog_i, exog_others).fit()
     res1c = OLS(res1a.resid, res1b.resid).fit()
@@ -273,67 +305,90 @@ def plot_partregress(endog, exog_i, exog_others, data=None,
 
     Parameters
     ----------
-    endog : ndarray or string
-       endogenous or response variable. If string is given, you can use a
+    endog : {ndarray, str}
+       The endogenous or response variable. If string is given, you can use a
        arbitrary translations as with a formula.
-    exog_i : ndarray or string
-        exogenous, explanatory variable. If string is given, you can use a
+    exog_i : {ndarray, str}
+        The exogenous, explanatory variable. If string is given, you can use a
         arbitrary translations as with a formula.
-    exog_others : ndarray or list of strings
-        other exogenous, explanatory variables. If a list of strings is given,
-        each item is a term in formula. You can use a arbitrary translations
-        as with a formula. The effect of these variables will be removed by
-        OLS regression.
-    data : DataFrame, dict, or recarray
+    exog_others : {ndarray, list[str]}
+        Any other exogenous, explanatory variables. If a list of strings is
+        given, each item is a term in formula. You can use a arbitrary
+        translations as with a formula. The effect of these variables will be
+        removed by OLS regression.
+    data : {DataFrame, dict}
         Some kind of data structure with names if the other variables are
         given as strings.
     title_kwargs : dict
         Keyword arguments to pass on for the title. The key to control the
         fonts is fontdict.
-    obs_labels : bool or array-like
+    obs_labels : {bool, array_like}
         Whether or not to annotate the plot points with their observation
         labels. If obs_labels is a boolean, the point labels will try to do
         the right thing. First it will try to use the index of data, then
         fall back to the index of exog_i. Alternatively, you may give an
-        array-like object corresponding to the obseveration numbers.
-    labels_kwargs : dict
+        array-like object corresponding to the observation numbers.
+    label_kwargs : dict
         Keyword arguments that control annotate for the observation labels.
-    ax : Matplotlib AxesSubplot instance, optional
+    ax : AxesSubplot, optional
         If given, this subplot is used to plot in instead of a new figure being
         created.
     ret_coords : bool
         If True will return the coordinates of the points in the plot. You
         can use this to add your own annotations.
-    kwargs
+    **kwargs
         The keyword arguments passed to plot for the points.
 
     Returns
     -------
-    fig : Matplotlib figure instance
+    fig : Figure
         If `ax` is None, the created figure.  Otherwise the figure to which
         `ax` is connected.
     coords : list, optional
         If ret_coords is True, return a tuple of arrays (x_coords, y_coords).
 
+    See Also
+    --------
+    plot_partregress_grid : Plot partial regression for a set of regressors.
+
     Notes
     -----
     The slope of the fitted line is the that of `exog_i` in the full
     multiple regression. The individual points can be used to assess the
     influence of points on the estimated coefficient.
 
-    See Also
+    Examples
     --------
-    plot_partregress_grid : Plot partial regression for a set of regressors.
+    Load the Statewide Crime data set and plot partial regression of the rate
+    of high school graduation (hs_grad) on the murder rate(murder).
+
+    The effects of the percent of the population living in urban areas (urban),
+    below the poverty line (poverty) , and in a single person household (single)
+    are removed by OLS regression.
+
+    >>> import statsmodels.api as sm
+    >>> import matplotlib.pyplot as plt
+
+    >>> crime_data = sm.datasets.statecrime.load_pandas()
+    >>> sm.graphics.plot_partregress(endog='murder', exog_i='hs_grad',
+    ...                              exog_others=['urban', 'poverty', 'single'],
+    ...                              data=crime_data.data, obs_labels=False)
+    >>> plt.show()
+
+    .. plot:: plots/graphics_regression_partregress.py
+
+    More detailed examples can be found in the Regression Plots notebook
+    on the examples page.
     """
     #NOTE: there is no interaction between possible missing data and
     #obs_labels yet, so this will need to be tweaked a bit for this case
     fig, ax = utils.create_mpl_ax(ax)
 
     # strings, use patsy to transform to data
-    if isinstance(endog, string_types):
+    if isinstance(endog, str):
         endog = dmatrix(endog + "-1", data)
 
-    if isinstance(exog_others, string_types):
+    if isinstance(exog_others, str):
         RHS = dmatrix(exog_others, data)
     elif isinstance(exog_others, list):
         RHS = "+".join(exog_others)
@@ -345,12 +400,14 @@ def plot_partregress(endog, exog_i, exog_others, data=None,
         RHS_isemtpy = True
     elif isinstance(RHS, pd.DataFrame) and RHS.empty:
         RHS_isemtpy = True
-    if isinstance(exog_i, string_types):
+    if isinstance(exog_i, str):
         exog_i = dmatrix(exog_i + "-1", data)
 
     # all arrays or pandas-like
 
     if RHS_isemtpy:
+        endog = np.asarray(endog)
+        exog_i = np.asarray(exog_i)
         ax.plot(endog, exog_i, 'o', **kwargs)
         fitted_line = OLS(endog, exog_i).fit()
         x_axis_endog_name = 'x' if isinstance(exog_i, np.ndarray) else exog_i.name
@@ -373,11 +430,11 @@ def plot_partregress(endog, exog_i, exog_others, data=None,
     ax.set_ylabel("e(%s | X)" % y_axis_endog_name)
     ax.set_title('Partial Regression Plot', **title_kwargs)
 
-    #NOTE: if we want to get super fancy, we could annotate if a point is
-    #clicked using this widget
-    #http://stackoverflow.com/questions/4652439/
-    #is-there-a-matplotlib-equivalent-of-matlabs-datacursormode/
-    #4674445#4674445
+    # NOTE: if we want to get super fancy, we could annotate if a point is
+    # clicked using this widget
+    # http://stackoverflow.com/questions/4652439/
+    # is-there-a-matplotlib-equivalent-of-matlabs-datacursormode/
+    # 4674445#4674445
     if obs_labels is True:
         if data is not None:
             obs_labels = data.index
@@ -390,7 +447,7 @@ def plot_partregress(endog, exog_i, exog_others, data=None,
         if obs_labels is None:
             obs_labels = lrange(len(exog_i))
 
-    if obs_labels is not False:  # could be array-like
+    if obs_labels is not False:  # could be array_like
         if len(obs_labels) != len(exog_i):
             raise ValueError("obs_labels does not match length of exog_i")
         label_kwargs.update(dict(ha="center", va="bottom"))
@@ -406,27 +463,35 @@ def plot_partregress(endog, exog_i, exog_others, data=None,
 
 
 def plot_partregress_grid(results, exog_idx=None, grid=None, fig=None):
-    """Plot partial regression for a set of regressors.
+    """
+    Plot partial regression for a set of regressors.
 
     Parameters
     ----------
-    results : results instance
-        A regression model results instance
-    exog_idx : None, list of ints, list of strings
-        (column) indices of the exog used in the plot, default is all.
-    grid : None or tuple of int (nrows, ncols)
+    results : Results instance
+        A regression model results instance.
+    exog_idx : {None, list[int], list[str]}
+        The indices  or column names of the exog used in the plot, default is
+        all.
+    grid : {None, tuple[int]}
         If grid is given, then it is used for the arrangement of the subplots.
-        If grid is None, then ncol is one, if there are only 2 subplots, and
-        the number of columns is two otherwise.
-    fig : Matplotlib figure instance, optional
+        The format of grid is  (nrows, ncols). If grid is None, then ncol is
+        one, if there are only 2 subplots, and the number of columns is two
+        otherwise.
+    fig : Figure, optional
         If given, this figure is simply returned.  Otherwise a new figure is
         created.
 
     Returns
     -------
-    fig : Matplotlib figure instance
+    Figure
         If `fig` is None, the created figure.  Otherwise `fig` itself.
 
+    See Also
+    --------
+    plot_partregress : Plot partial regression for a single regressor.
+    plot_ccpr : Plot CCPR against one regressor
+
     Notes
     -----
     A subplot is created for each explanatory variable given by exog_idx.
@@ -434,39 +499,49 @@ def plot_partregress_grid(results, exog_idx=None, grid=None, fig=None):
     and the given explanatory variable after removing the effect of all other
     explanatory variables in exog.
 
-    See Also
-    --------
-    plot_partregress : Plot partial regression for a single regressor.
-    plot_ccpr
-
     References
     ----------
     See http://www.itl.nist.gov/div898/software/dataplot/refman1/auxillar/partregr.htm
 
+    Examples
+    --------
+    Using the state crime dataset separately plot the effect of the each
+    variable on the on the outcome, murder rate while accounting for the effect
+    of all other variables in the model visualized with a grid of partial
+    regression plots.
+
+    >>> from statsmodels.graphics.regressionplots import plot_partregress_grid
+    >>> import statsmodels.api as sm
+    >>> import matplotlib.pyplot as plt
+    >>> import statsmodels.formula.api as smf
+
+    >>> fig = plt.figure(figsize=(8, 6))
+    >>> crime_data = sm.datasets.statecrime.load_pandas()
+    >>> results = smf.ols('murder ~ hs_grad + urban + poverty + single',
+    ...                   data=crime_data.data).fit()
+    >>> plot_partregress_grid(results, fig=fig)
+    >>> plt.show()
+
+    .. plot:: plots/graphics_regression_partregress_grid.py
     """
     import pandas
     fig = utils.create_mpl_fig(fig)
 
     exog_name, exog_idx = utils.maybe_name_or_idx(exog_idx, results.model)
 
-    #maybe add option for using wendog, wexog instead
+    # TODO: maybe add option for using wendog, wexog instead
     y = pandas.Series(results.model.endog, name=results.model.endog_names)
     exog = results.model.exog
 
     k_vars = exog.shape[1]
-    #this function doesn't make sense if k_vars=1
+    # this function does not make sense if k_vars=1
 
-    if not grid is None:
+    nrows = (len(exog_idx) + 1) // 2
+    ncols = 1 if nrows == len(exog_idx) else 2
+    if grid is not None:
         nrows, ncols = grid
-    else:
-        if len(exog_idx) > 2:
-            nrows = int(np.ceil(len(exog_idx)/2.))
-            ncols = 2
-            title_kwargs = {"fontdict" : {"fontsize" : 'small'}}
-        else:
-            nrows = len(exog_idx)
-            ncols = 1
-            title_kwargs = {}
+    if ncols > 1:
+        title_kwargs = {"fontdict": {"fontsize": 'small'}}
 
     # for indexing purposes
     other_names = np.array(results.model.exog_names)
@@ -475,7 +550,7 @@ def plot_partregress_grid(results, exog_idx=None, grid=None, fig=None):
         others.pop(idx)
         exog_others = pandas.DataFrame(exog[:, others],
                                        columns=other_names[others])
-        ax = fig.add_subplot(nrows, ncols, i+1)
+        ax = fig.add_subplot(nrows, ncols, i + 1)
         plot_partregress(y, pandas.Series(exog[:, idx],
                                           name=other_names[idx]),
                          exog_others, ax=ax, title_kwargs=title_kwargs,
@@ -483,33 +558,33 @@ def plot_partregress_grid(results, exog_idx=None, grid=None, fig=None):
         ax.set_title("")
 
     fig.suptitle("Partial Regression Plot", fontsize="large")
-
     fig.tight_layout()
-
     fig.subplots_adjust(top=.95)
+
     return fig
 
 
 def plot_ccpr(results, exog_idx, ax=None):
-    """Plot CCPR against one regressor.
+    """
+    Plot CCPR against one regressor.
 
-    Generates a CCPR (component and component-plus-residual) plot.
+    Generates a component and component-plus-residual (CCPR) plot.
 
     Parameters
     ----------
     results : result instance
         A regression results instance.
-    exog_idx : int or string
+    exog_idx : {int, str}
         Exogenous, explanatory variable. If string is given, it should
         be the variable name that you want to use, and you can use arbitrary
         translations as with a formula.
-    ax : Matplotlib AxesSubplot instance, optional
+    ax : AxesSubplot, optional
         If given, it is used to plot in instead of a new figure being
         created.
 
     Returns
     -------
-    fig : Matplotlib figure instance
+    Figure
         If `ax` is None, the created figure.  Otherwise the figure to which
         `ax` is connected.
 
@@ -531,6 +606,25 @@ def plot_ccpr(results, exog_idx, ax=None):
     References
     ----------
     http://www.itl.nist.gov/div898/software/dataplot/refman1/auxillar/ccpr.htm
+
+    Examples
+    --------
+    Using the state crime dataset plot the effect of the rate of single
+    households ('single') on the murder rate while accounting for high school
+    graduation rate ('hs_grad'), percentage of people in an urban area, and rate
+    of poverty ('poverty').
+
+    >>> import statsmodels.api as sm
+    >>> import matplotlib.pyplot as plot
+    >>> import statsmodels.formula.api as smf
+
+    >>> crime_data = sm.datasets.statecrime.load_pandas()
+    >>> results = smf.ols('murder ~ hs_grad + urban + poverty + single',
+    ...                   data=crime_data.data).fit()
+    >>> sm.graphics.plot_ccpr(results, 'single')
+    >>> plt.show()
+
+    .. plot:: plots/graphics_regression_ccpr.py
     """
     fig, ax = utils.create_mpl_ax(ax)
 
@@ -554,30 +648,35 @@ def plot_ccpr(results, exog_idx, ax=None):
 
 
 def plot_ccpr_grid(results, exog_idx=None, grid=None, fig=None):
-    """Generate CCPR plots against a set of regressors, plot in a grid.
+    """
+    Generate CCPR plots against a set of regressors, plot in a grid.
 
-    Generates a grid of CCPR (component and component-plus-residual) plots.
+    Generates a grid of component and component-plus-residual (CCPR) plots.
 
     Parameters
     ----------
     results : result instance
-        uses exog and params of the result instance
+        A results instance with exog and params.
     exog_idx : None or list of int
-        (column) indices of the exog used in the plot
+        The indices or column names of the exog used in the plot.
     grid : None or tuple of int (nrows, ncols)
         If grid is given, then it is used for the arrangement of the subplots.
         If grid is None, then ncol is one, if there are only 2 subplots, and
         the number of columns is two otherwise.
-    fig : Matplotlib figure instance, optional
+    fig : Figure, optional
         If given, this figure is simply returned.  Otherwise a new figure is
         created.
 
     Returns
     -------
-    fig : Matplotlib figure instance
+    Figure
         If `ax` is None, the created figure.  Otherwise the figure to which
         `ax` is connected.
 
+    See Also
+    --------
+    plot_ccpr : Creates CCPR plot for a single regressor.
+
     Notes
     -----
     Partial residual plots are formed as::
@@ -588,13 +687,28 @@ def plot_ccpr_grid(results, exog_idx=None, grid=None, fig=None):
 
         Betahat(i)*Xi versus Xi
 
-    See Also
-    --------
-    plot_ccpr : Creates CCPR plot for a single regressor.
-
     References
     ----------
     See http://www.itl.nist.gov/div898/software/dataplot/refman1/auxillar/ccpr.htm
+
+    Examples
+    --------
+    Using the state crime dataset separately plot the effect of the each
+    variable on the on the outcome, murder rate while accounting for the effect
+    of all other variables in the model.
+
+    >>> import statsmodels.api as sm
+    >>> import matplotlib.pyplot as plt
+    >>> import statsmodels.formula.api as smf
+
+    >>> fig = plt.figure(figsize=(8, 8))
+    >>> crime_data = sm.datasets.statecrime.load_pandas()
+    >>> results = smf.ols('murder ~ hs_grad + urban + poverty + single',
+    ...                   data=crime_data.data).fit()
+    >>> sm.graphics.plot_ccpr_grid(results, fig=fig)
+    >>> plt.show()
+
+    .. plot:: plots/graphics_regression_ccpr_grid.py
     """
     fig = utils.create_mpl_fig(fig)
 
@@ -631,33 +745,36 @@ def plot_ccpr_grid(results, exog_idx=None, grid=None, fig=None):
 def abline_plot(intercept=None, slope=None, horiz=None, vert=None,
                 model_results=None, ax=None, **kwargs):
     """
-    Plots a line given an intercept and slope.
+    Plot a line given an intercept and slope.
 
+    Parameters
+    ----------
     intercept : float
-        The intercept of the line
+        The intercept of the line.
     slope : float
-        The slope of the line
-    horiz : float or array-like
-        Data for horizontal lines on the y-axis
-    vert : array-like
-        Data for verterical lines on the x-axis
+        The slope of the line.
+    horiz : float or array_like
+        Data for horizontal lines on the y-axis.
+    vert : array_like
+        Data for verterical lines on the x-axis.
     model_results : statsmodels results instance
         Any object that has a two-value `params` attribute. Assumed that it
-        is (intercept, slope)
+        is (intercept, slope).
     ax : axes, optional
-        Matplotlib axes instance
-    kwargs
-        Options passed to matplotlib.pyplot.plt
+        Matplotlib axes instance.
+    **kwargs
+        Options passed to matplotlib.pyplot.plt.
 
     Returns
     -------
-    fig : Figure
+    Figure
         The figure given by `ax.figure` or a new instance.
 
     Examples
     --------
     >>> import numpy as np
     >>> import statsmodels.api as sm
+
     >>> np.random.seed(12345)
     >>> X = sm.add_constant(np.random.normal(0, 20, size=30))
     >>> y = np.dot(X, [25, 3.5]) + np.random.normal(0, 30, size=30)
@@ -668,8 +785,10 @@ def abline_plot(intercept=None, slope=None, horiz=None, vert=None,
     >>> ax.margins(.1)
     >>> import matplotlib.pyplot as plt
     >>> plt.show()
+
+    .. plot:: plots/graphics_regression_abline.py
     """
-    if ax is not None:  # get axis limits first thing, don't change these
+    if ax is not None:  # get axis limits first thing, do not change these
         x = ax.get_xlim()
     else:
         x = None
@@ -694,23 +813,34 @@ def abline_plot(intercept=None, slope=None, horiz=None, vert=None,
     from matplotlib.lines import Line2D
 
     class ABLine2D(Line2D):
+        def __init__(self, *args, **kwargs):
+            super(ABLine2D, self).__init__(*args, **kwargs)
+            self.id_xlim_callback = None
+            self.id_ylim_callback = None
+
+        def remove(self):
+            ax = self.axes
+            if self.id_xlim_callback:
+                ax.callbacks.disconnect(self.id_xlim_callback)
+            if self.id_ylim_callback:
+                ax.callbacks.disconnect(self.id_ylim_callback)
+            super(ABLine2D, self).remove()
 
         def update_datalim(self, ax):
             ax.set_autoscale_on(False)
-
             children = ax.get_children()
-            abline = [children[i] for i in range(len(children))
-                      if isinstance(children[i], ABLine2D)][0]
+            ablines = [child for child in children if child is self]
+            abline = ablines[0]
             x = ax.get_xlim()
-            y = [x[0]*slope+intercept, x[1]*slope+intercept]
+            y = [x[0] * slope + intercept, x[1] * slope + intercept]
             abline.set_data(x, y)
             ax.figure.canvas.draw()
-    #TODO: how to intercept something like a margins call and adjust?
 
+    # TODO: how to intercept something like a margins call and adjust?
     line = ABLine2D(x, data_y, **kwargs)
     ax.add_line(line)
-    ax.callbacks.connect('xlim_changed', line.update_datalim)
-    ax.callbacks.connect('ylim_changed', line.update_datalim)
+    line.id_xlim_callback = ax.callbacks.connect('xlim_changed', line.update_datalim)
+    line.id_ylim_callback = ax.callbacks.connect('ylim_changed', line.update_datalim)
 
     if horiz:
         ax.hline(horiz)
@@ -719,49 +849,17 @@ def abline_plot(intercept=None, slope=None, horiz=None, vert=None,
     return fig
 
 
-def influence_plot(results, external=True, alpha=.05, criterion="cooks",
-                   size=48, plot_alpha=.75, ax=None, **kwargs):
-    """
-    Plot of influence in regression. Plots studentized resids vs. leverage.
-
-    Parameters
-    ----------
-    results : results instance
-        A fitted model.
-    external : bool
-        Whether to use externally or internally studentized residuals. It is
-        recommended to leave external as True.
-    alpha : float
-        The alpha value to identify large studentized residuals. Large means
-        abs(resid_studentized) > t.ppf(1-alpha/2, dof=results.df_resid)
-    criterion : str {'DFFITS', 'Cooks'}
-        Which criterion to base the size of the points on. Options are
-        DFFITS or Cook's D.
-    size : float
-        The range of `criterion` is mapped to 10**2 - size**2 in points.
-    plot_alpha : float
-        The `alpha` of the plotted points.
-    ax : matplotlib Axes instance
-        An instance of a matplotlib Axes.
-
-    Returns
-    -------
-    fig : matplotlib figure
-        The matplotlib figure that contains the Axes.
-
-    Notes
-    -----
-    Row labels for the observations in which the leverage, measured by the
-    diagonal of the hat matrix, is high or the residuals are large, as the
-    combination of large residuals and a high influence value indicates an
-    influence point. The value of large residuals can be controlled using the
-    `alpha` parameter. Large leverage points are identified as
-    hat_i > 2 * (df_model + 1)/nobs.
-    """
+@Appender(_plot_influence_doc.format(**{
+    'extra_params_doc': "results: object\n"
+                        "        Results for a fitted regression model.\n"
+                        "    influence: instance\n"
+                        "        The instance of Influence for model."}))
+def _influence_plot(results, influence, external=True, alpha=.05,
+                    criterion="cooks", size=48, plot_alpha=.75, ax=None,
+                    **kwargs):
+    infl = influence
     fig, ax = utils.create_mpl_ax(ax)
 
-    infl = results.get_influence()
-
     if criterion.lower().startswith('coo'):
         psize = infl.cooks_distance[0]
     elif criterion.lower().startswith('dff'):
@@ -782,7 +880,7 @@ def influence_plot(results, external=True, alpha=.05, criterion="cooks",
     if external:
         resids = infl.resid_studentized_external
     else:
-        resids = infl.resid_studentized_internal
+        resids = infl.resid_studentized
 
     from scipy import stats
 
@@ -802,40 +900,41 @@ def influence_plot(results, external=True, alpha=.05, criterion="cooks",
                              lzip(-(psize/2)**.5, (psize/2)**.5), "x-large",
                              ax)
 
-    #TODO: make configurable or let people do it ex-post?
-    font = {"fontsize" : 16, "color" : "black"}
+    # TODO: make configurable or let people do it ex-post?
+    font = {"fontsize": 16, "color": "black"}
     ax.set_ylabel("Studentized Residuals", **font)
     ax.set_xlabel("H Leverage", **font)
     ax.set_title("Influence Plot", **font)
     return fig
 
 
-def plot_leverage_resid2(results, alpha=.05, ax=None,
+@Appender(_plot_influence_doc.format(**{
+    'extra_params_doc': "results : Results\n"
+                        "        Results for a fitted regression model."}))
+def influence_plot(results, external=True, alpha=.05, criterion="cooks",
+                   size=48, plot_alpha=.75, ax=None, **kwargs):
+
+    infl = results.get_influence()
+    res = _influence_plot(results, infl, external=external, alpha=alpha,
+                          criterion=criterion, size=size,
+                          plot_alpha=plot_alpha, ax=ax, **kwargs)
+    return res
+
+
+@Appender(_plot_leverage_resid2_doc.format({
+    'extra_params_doc': "results: object\n"
+                        "    Results for a fitted regression model\n"
+                        "influence: instance\n"
+                        "    instance of Influence for model"}))
+def _plot_leverage_resid2(results, influence, alpha=.05, ax=None,
                          **kwargs):
-    """
-    Plots leverage statistics vs. normalized residuals squared
 
-    Parameters
-    ----------
-    results : results instance
-        A regression results instance
-    alpha : float
-        Specifies the cut-off for large-standardized residuals. Residuals
-        are assumed to be distributed N(0, 1) with alpha=alpha.
-    ax : Axes instance
-        Matplotlib Axes instance
-
-    Returns
-    -------
-    fig : matplotlib Figure
-        A matplotlib figure instance.
-    """
     from scipy.stats import zscore, norm
     fig, ax = utils.create_mpl_ax(ax)
 
-    infl = results.get_influence()
+    infl = influence
     leverage = infl.hat_matrix_diag
-    resid = zscore(results.resid)
+    resid = zscore(infl.resid)
     ax.plot(resid**2, leverage, 'o', **kwargs)
     ax.set_xlabel("Normalized residuals**2")
     ax.set_ylabel("Leverage")
@@ -855,9 +954,22 @@ def plot_leverage_resid2(results, alpha=.05, ax=None,
     ax.margins(.075, .075)
     return fig
 
+
+@Appender(_plot_leverage_resid2_doc.format({
+    'extra_params_doc': "results : object\n"
+                        "    Results for a fitted regression model"}))
+def plot_leverage_resid2(results, alpha=.05, ax=None, **kwargs):
+
+    infl = results.get_influence()
+    return _plot_leverage_resid2(results, infl, alpha=alpha, ax=ax, **kwargs)
+
+
+
+@Appender(_plot_added_variable_doc % {
+    'extra_params_doc': "results : object\n"
+                        "    Results for a fitted regression model"})
 def plot_added_variable(results, focus_exog, resid_type=None,
                         use_glm_weights=True, fit_kwargs=None, ax=None):
-    # Docstring attached below
 
     model = results.model
 
@@ -873,7 +985,7 @@ def plot_added_variable(results, focus_exog, resid_type=None,
 
     ax.set_title('Added variable plot', fontsize='large')
 
-    if type(focus_exog) is str:
+    if isinstance(focus_exog, str):
         xname = focus_exog
     else:
         xname = model.exog_names[focus_exog]
@@ -882,9 +994,10 @@ def plot_added_variable(results, focus_exog, resid_type=None,
 
     return fig
 
-plot_added_variable.__doc__ = _plot_added_variable_doc % {
-    'extra_params_doc' : "results: object\n\tResults for a fitted regression model"}
 
+@Appender(_plot_partial_residuals_doc % {
+    'extra_params_doc': "results : object\n"
+                        "    Results for a fitted regression model"})
 def plot_partial_residuals(results, focus_exog, ax=None):
     # Docstring attached below
 
@@ -900,7 +1013,7 @@ def plot_partial_residuals(results, focus_exog, ax=None):
 
     ax.set_title('Partial residuals plot', fontsize='large')
 
-    if type(focus_exog) is str:
+    if isinstance(focus_exog, str):
         xname = focus_exog
     else:
         xname = model.exog_names[focus_exog]
@@ -909,12 +1022,13 @@ def plot_partial_residuals(results, focus_exog, ax=None):
 
     return fig
 
-plot_partial_residuals.__doc__ = _plot_partial_residuals_doc % {
-    'extra_params_doc' : "results: object\n\tResults for a fitted regression model"}
 
+@Appender(_plot_ceres_residuals_doc % {
+    'extra_params_doc': "results : Results\n"
+                        "        Results instance of a fitted regression "
+                        "model."})
 def plot_ceres_residuals(results, focus_exog, frac=0.66, cond_means=None,
-               ax=None):
-    # Docstring attached below
+                         ax=None):
 
     model = results.model
 
@@ -935,8 +1049,6 @@ def plot_ceres_residuals(results, focus_exog, frac=0.66, cond_means=None,
 
     return fig
 
-plot_ceres_residuals.__doc__ = _plot_ceres_residuals_doc % {
-    'extra_params_doc' : "results: object\n\tResults for a fitted regression model"}
 
 def ceres_resids(results, focus_exog, frac=0.66, cond_means=None):
     """
@@ -952,7 +1064,7 @@ def ceres_resids(results, focus_exog, frac=0.66, cond_means=None):
     frac : float, optional
         Lowess smoothing parameter for estimating the conditional
         means.  Not used if `cond_means` is provided.
-    cond_means : array-like, optional
+    cond_means : array_like, optional
         If provided, the columns of this array are the conditional
         means E[exog | focus exog], where exog ranges over some
         or all of the columns of exog other than focus exog.  If
@@ -990,7 +1102,7 @@ def ceres_resids(results, focus_exog, frac=0.66, cond_means=None):
     if cond_means is None:
 
         # Below we calculate E[x | focus] where x is each column other
-        # than the focus column.  We don't want the intercept when we do
+        # than the focus column.  We do not want the intercept when we do
         # this so we remove it here.
         pexog = model.exog[:, ix_nf]
         pexog -= pexog.mean(0)
@@ -1086,10 +1198,10 @@ def added_variable_resids(results, focus_exog, resid_type=None,
     results : regression results instance
         A fitted model including the focus exog and all other
         predictors of interest.
-    focus_exog : integer or string
+    focus_exog : {int, str}
         The column of results.model.exog or a variable name that is
         to be residualized against the other predictors.
-    resid_type : string
+    resid_type : str
         The type of residuals to use for the dependent variable.  If
         None, uses `resid_deviance` for GLM/GEE and `resid` otherwise.
     use_glm_weights : bool
@@ -1103,9 +1215,9 @@ def added_variable_resids(results, focus_exog, resid_type=None,
 
     Returns
     -------
-    endog_resid : array-like
+    endog_resid : array_like
         The residuals for the original exog
-    focus_exog_resid : array-like
+    focus_exog_resid : array_like
         The residuals for the focus predictor
 
     Notes
