@@ -26,7 +26,7 @@ License: BSD
 TODO
 ----
 * add starting values based on OLS
-* bugs: store_params doesn't seem to be defined, I think this was a module
+* bugs: store_params does not seem to be defined, I think this was a module
         global for debugging - commented out
 * parameter restriction: check whether version with some fixed parameters works
 
@@ -35,15 +35,18 @@ TODO
 #mostly copied from the examples directory written for trying out generic mle.
 
 import numpy as np
-from scipy import special #, stats
+from scipy import special, stats
+
+from statsmodels.base.model import GenericLikelihoodModel
+from statsmodels.tsa.arma_mle import Arma
+
+
 #redefine some shortcuts
 np_log = np.log
 np_pi = np.pi
 sps_gamln = special.gammaln
 
 
-from statsmodels.base.model import GenericLikelihoodModel
-
 class TLinearModel(GenericLikelihoodModel):
     '''Maximum Likelihood Estimation of Linear Model with t-distributed errors
 
@@ -117,19 +120,19 @@ class TLinearModel(GenericLikelihoodModel):
 
         Parameters
         ----------
-        params : array
+        params : ndarray
             The parameters of the model. The last 2 parameters are degrees of
             freedom and scale.
 
         Returns
         -------
-        loglike : array, (nobs,)
+        loglike : ndarray
             The log likelihood of the model evaluated at `params` for each
             observation defined by self.endog and self.exog.
 
         Notes
         -----
-        .. math :: \\ln L=\\sum_{i=1}^{n}\\left[-\\lambda_{i}+y_{i}x_{i}^{\\prime}\\beta-\\ln y_{i}!\\right]
+        .. math:: \\ln L=\\sum_{i=1}^{n}\\left[-\\lambda_{i}+y_{i}x_{i}^{\\prime}\\beta-\\ln y_{i}!\\right]
 
         The t distribution is the standard t distribution and not a standardized
         t distribution, which means that the scale parameter is not equal to the
@@ -137,11 +140,10 @@ class TLinearModel(GenericLikelihoodModel):
 
         self.fixed_params and self.expandparams can be used to fix some
         parameters. (I doubt this has been tested in this model.)
-
         """
         #print len(params),
         #store_params.append(params)
-        if not self.fixed_params is None:
+        if self.fixed_params is not None:
             #print 'using fixed'
             params = self.expandparams(params)
 
@@ -163,9 +165,6 @@ class TLinearModel(GenericLikelihoodModel):
         return np.dot(exog, params[:self.exog.shape[1]])
 
 
-from scipy import stats
-from statsmodels.tsa.arma_mle import Arma
-
 class TArma(Arma):
     '''Univariate Arma Model with t-distributed errors
 
