@@ -12,6 +12,7 @@ from scipy import stats
 from statsmodels.sandbox.nonparametric import kernels
 from statsmodels.distributions.mixture_rvs import mixture_rvs
 from statsmodels.nonparametric.bandwidths import select_bandwidth
+from statsmodels.nonparametric.bandwidths import bw_normal_reference
 
 
 from numpy.testing import assert_allclose
@@ -40,6 +41,12 @@ class TestBandwidthCalculation(object):
 
         assert_allclose(bw_expected, bw_calc)
 
+    def test_calculate_normal_reference_bandwidth(self):
+        # Should be the same as the Gaussian Kernel
+        bw_expected = 0.29781147113698891
+        bw = bw_normal_reference(Xi)
+        assert_allclose(bw, bw_expected)
+
 
 class CheckNormalReferenceConstant(object):
 
