@@ -13,8 +13,8 @@
 
 TODO:
 * Where is Transf_gen for general monotonic transformation ? found and added it
-* write some docstrings, some parts I don't remember
-* add Box-Cox transformation, parameterized ?
+* write some docstrings, some parts I do not remember
+* add Box-Cox transformation, parametrized ?
 
 
 this is only partially cleaned, still includes test examples as functions
@@ -50,14 +50,18 @@ License: BSD
 
 '''
 
+import numpy as np
+from numpy import poly1d,sqrt, exp
+
+import scipy
+from scipy import stats, special
+from scipy.stats import distributions
+
+from statsmodels.stats.moment_helpers import mvsk2mc, mc2mvsk
+
+
 #note copied from distr_skewnorm_0.py
 
-from __future__ import print_function
-from statsmodels.compat.python import range, iteritems
-from scipy import stats, special, integrate  # integrate is for scipy 0.6.0 ???
-from scipy.stats import distributions
-from statsmodels.stats.moment_helpers import mvsk2mc, mc2mvsk
-import numpy as np
 
 class SkewNorm_gen(distributions.rv_continuous):
     '''univariate Skew-Normal distribution of Azzalini
@@ -208,8 +212,6 @@ appears in J.Roy.Statist.Soc, series B, vol.65, pp.367-389
 ##    return (mc, mc2, mc3, mc4)
 
 
-from numpy import poly1d,sqrt, exp
-import scipy
 def _hermnorm(N):
     # return the negatively normalized hermite polynomials up to order N-1
     #  (inclusive)
@@ -228,7 +230,6 @@ def pdf_moments_st(cnt):
 
     version of scipy.stats, any changes ?
     the scipy.stats version has a bug and returns normal distribution
-
     """
 
     N = len(cnt)
@@ -298,7 +299,7 @@ def pdf_mvsk(mvsk):
 
     References
     ----------
-    http://en.wikipedia.org/wiki/Edgeworth_series
+    https://en.wikipedia.org/wiki/Edgeworth_series
     Johnson N.L., S. Kotz, N. Balakrishnan: Continuous Univariate
     Distributions, Volume 1, 2nd ed., p.30
     """
@@ -346,7 +347,7 @@ def pdf_moments(cnt):
 
     References
     ----------
-    http://en.wikipedia.org/wiki/Edgeworth_series
+    https://en.wikipedia.org/wiki/Edgeworth_series
     Johnson N.L., S. Kotz, N. Balakrishnan: Continuous Univariate
     Distributions, Volume 1, 2nd ed., p.30
     """
@@ -411,7 +412,7 @@ class NormExpan_gen(distributions.rv_continuous):
         where xc = (x-mu)/sig is the standardized value of the random variable
         and H(xc,3) and H(xc,4) are Hermite polynomials
 
-        Note: This distribution has to be parameterized during
+        Note: This distribution has to be parametrized during
         initialization and instantiation, and does not have a shape
         parameter after instantiation (similar to frozen distribution
         except for location and scale.) Location and scale can be used
@@ -488,15 +489,10 @@ License: BSD
 
 '''
 
-from scipy import integrate # for scipy 0.6.0
-
-from scipy import stats, info
-from scipy.stats import distributions
-
 
 def get_u_argskwargs(**kwargs):
     #Todo: What's this? wrong spacing, used in Transf_gen TransfTwo_gen
-    u_kwargs = dict((k.replace('u_','',1),v) for k,v in iteritems(kwargs)
+    u_kwargs = dict((k.replace('u_','',1),v) for k,v in kwargs.items()
                     if k.startswith('u_'))
     u_args = u_kwargs.pop('u_args',None)
     return u_args, u_kwargs
@@ -526,8 +522,8 @@ class Transf_gen(distributions.rv_continuous):
 
 
         self.u_args, self.u_kwargs = get_u_argskwargs(**kwargs)
-        self.kls = kls   #(self.u_args, self.u_kwargs)
-                         # possible to freeze the underlying distribution
+        self.kls = kls  #(self.u_args, self.u_kwargs)
+                        # possible to freeze the underlying distribution
 
         super(Transf_gen,self).__init__(a=a, b=b, name = name,
                                 longname = longname, extradoc = extradoc)
@@ -583,9 +579,6 @@ loggammaexpg = Transf_gen(stats.gamma, np.log, np.exp, numargs=1)
 random variable
 
 '''
-from scipy import stats
-from scipy.stats import distributions
-import numpy as np
 
 class ExpTransf_gen(distributions.rv_continuous):
     '''Distribution based on log/exp transformation
@@ -731,8 +724,8 @@ class TransfTwo_gen(distributions.rv_continuous):
 
 
         self.u_args, self.u_kwargs = get_u_argskwargs(**kwargs)
-        self.kls = kls   #(self.u_args, self.u_kwargs)
-                         # possible to freeze the underlying distribution
+        self.kls = kls  #(self.u_args, self.u_kwargs)
+                        # possible to freeze the underlying distribution
 
         super(TransfTwo_gen,self).__init__(a=a, b=b, name = name,
                                 shapes = kls.shapes,
@@ -799,7 +792,7 @@ class SquareFunc(object):
     '''class to hold quadratic function with inverse function and derivative
 
     using instance methods instead of class methods, if we want extension
-    to parameterized function
+    to parametrized function
     '''
     def inverseplus(self, x):
         return np.sqrt(x)
@@ -910,7 +903,7 @@ a wrapper for scipy.stats.kde.mvndst
 *     CORREL REAL, array of correlation coefficients; the correlation
 *            coefficient in row I column J of the correlation matrix
 *            should be stored in CORREL( J + ((I-2)*(I-1))/2 ), for J < I.
-*            THe correlation matrix must be positive semidefinite.
+*            The correlation matrix must be positive semidefinite.
 *     MAXPTS INTEGER, maximum number of function values allowed. This
 *            parameter can be used to limit the time. A sensible
 *            strategy is to start with MAXPTS = 1000*N, and then
@@ -1030,7 +1023,7 @@ def mvstdnormcdf(lower, upper, corrcoef, **kwds):
 
     '''
     n = len(lower)
-    #don't know if converting to array is necessary,
+    #do not know if converting to array is necessary,
     #but it makes ndim check possible
     lower = np.array(lower)
     upper = np.array(upper)
@@ -1057,7 +1050,7 @@ def mvstdnormcdf(lower, upper, corrcoef, **kwds):
     else:
         raise ValueError('corrcoef has incorrect dimension')
 
-    if not 'maxpts' in kwds:
+    if 'maxpts' not in kwds:
         if n >2:
             kwds['maxpts'] = 10000*n
 
@@ -1139,9 +1132,3 @@ def mvnormcdf(upper, mu, cov, lower=None,  **kwds):
     #v/np.sqrt(np.atleast_2d(np.diag(covv)))/np.sqrt(np.atleast_2d(np.diag(covv))).T
 
     return mvstdnormcdf(lower, upper, corr, **kwds)
-
-
-
-
-if __name__ == '__main__':
-    examples_transf()
