@@ -170,7 +170,7 @@ class CustomKernel(object):
         def isInDomain(xy):
             """Used for filter to check if point is in the domain"""
             u = (xy[0]-x)/self.h
-            return u >= self.domain[0] and u <= self.domain[1]
+            return np.all((u >= self.domain[0]) & (u <= self.domain[1]))
 
         if self.domain is None:
             return (xs, ys)
@@ -449,7 +449,7 @@ class Biweight(CustomKernel):
         xs and y-values ys.
         Not expected to be called by the user.
 
-        Special implementation optimised for Biweight.
+        Special implementation optimized for Biweight.
         """
         xs, ys = self.in_domain(xs, ys, x)
 
@@ -527,7 +527,7 @@ class Gaussian(CustomKernel):
         xs and y-values ys.
         Not expected to be called by the user.
 
-        Special implementation optimised for Gaussian.
+        Special implementation optimized for Gaussian.
         """
         w = np.sum(exp(multiply(square(divide(subtract(xs, x),
                                               self.h)),-0.5)))
