@@ -1,7 +1,6 @@
 """
 Compatibility tools for various data structure inputs
 """
-from statsmodels.compat.python import range
 import numpy as np
 import pandas as pd
 
@@ -11,8 +10,10 @@ def _check_period_index(x, freq="M"):
     if not isinstance(x.index, (DatetimeIndex, PeriodIndex)):
         raise ValueError("The index must be a DatetimeIndex or PeriodIndex")
 
-    from statsmodels.tsa.base.datetools import _infer_freq
-    inferred_freq = _infer_freq(x.index)
+    if x.index.freq is not None:
+        inferred_freq = x.index.freqstr
+    else:
+        inferred_freq = pd.infer_freq(x.index)
     if not inferred_freq.startswith(freq):
         raise ValueError("Expected frequency {}. Got {}".format(inferred_freq,
                                                                 freq))
@@ -37,7 +38,7 @@ def interpret_data(data, colnames=None, rownames=None):
 
     Parameters
     ----------
-    data : ndarray-like
+    data : array_like
     colnames : sequence or None
         May be part of data structure
     rownames : sequence or None
@@ -48,6 +49,9 @@ def interpret_data(data, colnames=None, rownames=None):
     """
     if isinstance(data, np.ndarray):
         if _is_structured_ndarray(data):
+            import warnings
+            from statsmodels.tools.sm_exceptions import recarray_warning
+            warnings.warn(recarray_warning, FutureWarning)
             if colnames is None:
                 colnames = data.dtype.names
             values = struct_to_ndarray(data)
@@ -63,7 +67,8 @@ def interpret_data(data, colnames=None, rownames=None):
         colnames = data.columns
         rownames = data.index
     else:  # pragma: no cover
-        raise Exception('cannot handle other input types at the moment')
+        raise TypeError('Cannot handle input type {typ}'
+                        .format(typ=type(data).__name__))
 
     if not isinstance(colnames, list):
         colnames = list(colnames)
@@ -81,7 +86,7 @@ def interpret_data(data, colnames=None, rownames=None):
 
 
 def struct_to_ndarray(arr):
-    return arr.view((float, len(arr.dtype.names)), type=np.ndarray)
+    return arr.view((float, (len(arr.dtype.names),)), type=np.ndarray)
 
 
 def _is_using_ndarray_type(endog, exog):
@@ -95,8 +100,7 @@ def _is_using_ndarray(endog, exog):
 
 
 def _is_using_pandas(endog, exog):
-    # TODO: Remove WidePanel when finished with it
-    klasses = (pd.Series, pd.DataFrame, pd.WidePanel, pd.Panel)
+    from statsmodels.compat.pandas import data_klasses as klasses
     return (isinstance(endog, klasses) or isinstance(exog, klasses))
 
 
