@@ -5,24 +5,25 @@ Vector Autoregressive Moving Average with eXogenous regressors model
 Author: Chad Fulton
 License: Simplified-BSD
 """
-from __future__ import division, absolute_import, print_function
 
+import contextlib
 from warnings import warn
-from collections import OrderedDict
 
 import pandas as pd
 import numpy as np
 
+from statsmodels.compat.pandas import Appender
 from statsmodels.tools.tools import Bunch
 from statsmodels.tools.data import _is_using_pandas
 from statsmodels.tsa.vector_ar import var_model
 import statsmodels.base.wrapper as wrap
-from statsmodels.tools.sm_exceptions import EstimationWarning, ValueWarning
+from statsmodels.tools.sm_exceptions import EstimationWarning
 
 from .kalman_filter import INVERT_UNIVARIATE, SOLVE_LU
 from .mlemodel import MLEModel, MLEResults, MLEResultsWrapper
+from .initialization import Initialization
 from .tools import (
-    is_invertible, prepare_exog,
+    is_invertible, concat, prepare_exog,
     constrain_stationary_multivariate, unconstrain_stationary_multivariate,
     prepare_trend_spec, prepare_trend_data
 )
@@ -46,24 +47,28 @@ class VARMAX(MLEModel):
         Can be specified as a string where 'c' indicates a constant (i.e. a
         degree zero component of the trend polynomial), 't' indicates a
         linear trend with time, and 'ct' is both. Can also be specified as an
-        iterable defining the polynomial as in `numpy.poly1d`, where
-        `[1,1,0,1]` would denote :math:`a + bt + ct^3`. Default is a constant
-        trend component.
+        iterable defining the non-zero polynomial exponents to include, in
+        increasing order. For example, `[1,1,0,1]` denotes
+        :math:`a + bt + ct^3`. Default is a constant trend component.
     error_cov_type : {'diagonal', 'unstructured'}, optional
         The structure of the covariance matrix of the error term, where
         "unstructured" puts no restrictions on the matrix and "diagonal"
         requires it to be a diagonal matrix (uncorrelated errors). Default is
         "unstructured".
-    measurement_error : boolean, optional
+    measurement_error : bool, optional
         Whether or not to assume the endogenous observations `endog` were
         measured with error. Default is False.
-    enforce_stationarity : boolean, optional
+    enforce_stationarity : bool, optional
         Whether or not to transform the AR parameters to enforce stationarity
         in the autoregressive component of the model. Default is True.
-    enforce_invertibility : boolean, optional
+    enforce_invertibility : bool, optional
         Whether or not to transform the MA parameters to enforce invertibility
         in the moving average component of the model. Default is True.
-    kwargs
+    trend_offset : int, optional
+        The offset at which to start time trend values. Default is 1, so that
+        if `trend='t'` the trend is equal to 1, 2, ..., nobs. Typically is only
+        set when the model created by extending a previous dataset.
+    **kwargs
         Keyword arguments may be used to provide default values for state space
         matrices or for Kalman filtering options. See `Representation`, and
         `KalmanFilter` for more details.
@@ -78,20 +83,21 @@ class VARMAX(MLEModel):
         Can be specified as a string where 'c' indicates a constant (i.e. a
         degree zero component of the trend polynomial), 't' indicates a
         linear trend with time, and 'ct' is both. Can also be specified as an
-        iterable defining the polynomial as in `numpy.poly1d`, where
-        `[1,1,0,1]` would denote :math:`a + bt + ct^3`.
+        iterable defining the non-zero polynomial exponents to include, in
+        increasing order. For example, `[1,1,0,1]` denotes
+        :math:`a + bt + ct^3`.
     error_cov_type : {'diagonal', 'unstructured'}, optional
         The structure of the covariance matrix of the error term, where
         "unstructured" puts no restrictions on the matrix and "diagonal"
         requires it to be a diagonal matrix (uncorrelated errors). Default is
         "unstructured".
-    measurement_error : boolean, optional
+    measurement_error : bool, optional
         Whether or not to assume the endogenous observations `endog` were
         measured with error. Default is False.
-    enforce_stationarity : boolean, optional
+    enforce_stationarity : bool, optional
         Whether or not to transform the AR parameters to enforce stationarity
         in the autoregressive component of the model. Default is True.
-    enforce_invertibility : boolean, optional
+    enforce_invertibility : bool, optional
         Whether or not to transform the MA parameters to enforce invertibility
         in the moving average component of the model. Default is True.
 
@@ -122,13 +128,12 @@ class VARMAX(MLEModel):
     .. [1] Lütkepohl, Helmut. 2007.
        New Introduction to Multiple Time Series Analysis.
        Berlin: Springer.
-
     """
 
     def __init__(self, endog, exog=None, order=(1, 0), trend='c',
                  error_cov_type='unstructured', measurement_error=False,
                  enforce_stationarity=True, enforce_invertibility=True,
-                 **kwargs):
+                 trend_offset=1, **kwargs):
 
         # Model parameters
         self.error_cov_type = error_cov_type
@@ -138,7 +143,6 @@ class VARMAX(MLEModel):
 
         # Save the given orders
         self.order = order
-        self.trend = trend
 
         # Model orders
         self.k_ar = int(order[0])
@@ -160,6 +164,7 @@ class VARMAX(MLEModel):
 
         # Trend
         self.trend = trend
+        self.trend_offset = trend_offset
         self.polynomial_trend, self.k_trend = prepare_trend_spec(self.trend)
         self._trend_is_const = (self.polynomial_trend.size == 1 and
                                 self.polynomial_trend[0] == 1)
@@ -201,7 +206,7 @@ class VARMAX(MLEModel):
             self.ssm._time_invariant = False
 
         # Initialize the parameters
-        self.parameters = OrderedDict()
+        self.parameters = {}
         self.parameters['trend'] = self.k_endog * self.k_trend
         self.parameters['ar'] = self.k_endog**2 * self.k_ar
         self.parameters['ma'] = self.k_endog**2 * self.k_ma
@@ -217,9 +222,14 @@ class VARMAX(MLEModel):
         self.parameters['obs_cov'] = self.k_endog * self.measurement_error
         self.k_params = sum(self.parameters.values())
 
-        # Initialize trend data
-        self._trend_data = prepare_trend_data(
-            self.polynomial_trend, self.k_trend, self.nobs, offset=1)
+        # Initialize trend data: we create trend data with one more observation
+        # than we actually have, to make it easier to insert the appropriate
+        # trend component into the final state intercept.
+        trend_data = prepare_trend_data(
+            self.polynomial_trend, self.k_trend, self.nobs + 1,
+            offset=self.trend_offset)
+        self._trend_data = trend_data[:-1]
+        self._final_trend = trend_data[-1:]
 
         # Initialize known elements of the state space matrices
 
@@ -290,6 +300,18 @@ class VARMAX(MLEModel):
         self._params_state_cov, offset = _slice('state_cov', offset)
         self._params_obs_cov, offset = _slice('obs_cov', offset)
 
+        # Variable holding optional final `exog`
+        # (note: self._final_trend was set earlier)
+        self._final_exog = None
+
+        # Update _init_keys attached by super
+        self._init_keys += ['order', 'trend', 'error_cov_type',
+                            'measurement_error', 'enforce_stationarity',
+                            'enforce_invertibility'] + list(kwargs.keys())
+
+    def clone(self, endog, exog=None, **kwargs):
+        return self._clone_from_init_kwds(endog, exog=exog, **kwargs)
+
     @property
     def _res_classes(self):
         return {'fit': (VARMAXResults, VARMAXResultsWrapper)}
@@ -300,12 +322,7 @@ class VARMAX(MLEModel):
 
         # A. Run a multivariate regression to get beta estimates
         endog = pd.DataFrame(self.endog.copy())
-        # Pandas < 0.13 didn't support the same type of DataFrame interpolation
-        # TODO remove this now that we have dropped support for Pandas < 0.13
-        try:
-            endog = endog.interpolate()
-        except TypeError:
-            pass
+        endog = endog.interpolate()
         endog = endog.fillna(method='backfill').values
         exog = None
         if self.k_trend > 0 and self.k_exog > 0:
@@ -381,7 +398,7 @@ class VARMAX(MLEModel):
                     ma_params *= 0
 
         # Transform trend / exog params from mean form to intercept form
-        if self.k_ar > 0 and self.k_trend > 0 or self.mle_regression:
+        if self.k_ar > 0 and (self.k_trend > 0 or self.mle_regression):
             coefficient_matrices = (
                 ar_params.reshape(
                     self.k_endog * self.k_ar, self.k_endog
@@ -431,23 +448,24 @@ class VARMAX(MLEModel):
     @property
     def param_names(self):
         param_names = []
+        endog_names = self.endog_names
+        if not isinstance(self.endog_names, list):
+            endog_names = [endog_names]
 
         # 1. Intercept terms
         if self.k_trend > 0:
-            for i in self.polynomial_trend.nonzero()[0]:
-                if i == 0:
-                    param_names += ['intercept.%s' % self.endog_names[j]
-                                    for j in range(self.k_endog)]
-                elif i == 1:
-                    param_names += ['drift.%s' % self.endog_names[j]
-                                    for j in range(self.k_endog)]
-                else:
-                    param_names += ['trend.%d.%s' % (i, self.endog_names[j])
-                                    for j in range(self.k_endog)]
+            for j in range(self.k_endog):
+                for i in self.polynomial_trend.nonzero()[0]:
+                    if i == 0:
+                        param_names += ['intercept.%s' % endog_names[j]]
+                    elif i == 1:
+                        param_names += ['drift.%s' % endog_names[j]]
+                    else:
+                        param_names += ['trend.%d.%s' % (i, endog_names[j])]
 
         # 2. AR terms
         param_names += [
-            'L%d.%s.%s' % (i+1, self.endog_names[k], self.endog_names[j])
+            'L%d.%s.%s' % (i+1, endog_names[k], endog_names[j])
             for j in range(self.k_endog)
             for i in range(self.k_ar)
             for k in range(self.k_endog)
@@ -455,7 +473,7 @@ class VARMAX(MLEModel):
 
         # 3. MA terms
         param_names += [
-            'L%d.e(%s).%s' % (i+1, self.endog_names[k], self.endog_names[j])
+            'L%d.e(%s).%s' % (i+1, endog_names[k], endog_names[j])
             for j in range(self.k_endog)
             for i in range(self.k_ma)
             for k in range(self.k_endog)
@@ -463,7 +481,7 @@ class VARMAX(MLEModel):
 
         # 4. Regression terms
         param_names += [
-            'beta.%s.%s' % (self.exog_names[j], self.endog_names[i])
+            'beta.%s.%s' % (self.exog_names[j], endog_names[i])
             for i in range(self.k_endog)
             for j in range(self.k_exog)
         ]
@@ -471,13 +489,13 @@ class VARMAX(MLEModel):
         # 5. State covariance terms
         if self.error_cov_type == 'diagonal':
             param_names += [
-                'sigma2.%s' % self.endog_names[i]
+                'sigma2.%s' % endog_names[i]
                 for i in range(self.k_endog)
             ]
         elif self.error_cov_type == 'unstructured':
             param_names += [
-                ('sqrt.var.%s' % self.endog_names[i] if i == j else
-                 'sqrt.cov.%s.%s' % (self.endog_names[j], self.endog_names[i]))
+                ('sqrt.var.%s' % endog_names[i] if i == j else
+                 'sqrt.cov.%s.%s' % (endog_names[j], endog_names[i]))
                 for i in range(self.k_endog)
                 for j in range(i+1)
             ]
@@ -485,7 +503,7 @@ class VARMAX(MLEModel):
         # 5. Measurement error variance terms
         if self.measurement_error:
             param_names += [
-                'measurement_variance.%s' % self.endog_names[i]
+                'measurement_variance.%s' % endog_names[i]
                 for i in range(self.k_endog)
             ]
 
@@ -506,7 +524,7 @@ class VARMAX(MLEModel):
         -------
         constrained : array_like
             Array of constrained parameters which may be used in likelihood
-            evalation.
+            evaluation.
 
         Notes
         -----
@@ -582,8 +600,8 @@ class VARMAX(MLEModel):
         Parameters
         ----------
         constrained : array_like
-            Array of constrained parameters used in likelihood evalution, to be
-            transformed.
+            Array of constrained parameters used in likelihood evaluation, to
+            be transformed.
 
         Returns
         -------
@@ -651,8 +669,40 @@ class VARMAX(MLEModel):
 
         return unconstrained
 
-    def update(self, params, **kwargs):
-        params = super(VARMAX, self).update(params, **kwargs)
+    def _validate_can_fix_params(self, param_names):
+        super(VARMAX, self)._validate_can_fix_params(param_names)
+
+        ix = np.cumsum(list(self.parameters.values()))[:-1]
+        (_, ar_names, ma_names, _, _, _) = [
+            arr.tolist() for arr in np.array_split(self.param_names, ix)]
+
+        if self.enforce_stationarity and self.k_ar > 0:
+            if self.k_endog > 1 or self.k_ar > 1:
+                fix_all = param_names.issuperset(ar_names)
+                fix_any = (
+                    len(param_names.intersection(ar_names)) > 0)
+                if fix_any and not fix_all:
+                    raise ValueError(
+                        'Cannot fix individual autoregressive parameters'
+                        ' when `enforce_stationarity=True`. In this case,'
+                        ' must either fix all autoregressive parameters or'
+                        ' none.')
+        if self.enforce_invertibility and self.k_ma > 0:
+            if self.k_endog or self.k_ma > 1:
+                fix_all = param_names.issuperset(ma_names)
+                fix_any = (
+                    len(param_names.intersection(ma_names)) > 0)
+                if fix_any and not fix_all:
+                    raise ValueError(
+                        'Cannot fix individual moving average parameters'
+                        ' when `enforce_invertibility=True`. In this case,'
+                        ' must either fix all moving average parameters or'
+                        ' none.')
+
+    def update(self, params, transformed=True, includes_fixed=False,
+               complex_step=False):
+        params = self.handle_params(params, transformed=transformed,
+                                    includes_fixed=includes_fixed)
 
         # 1. State intercept
         # - Exog
@@ -662,13 +712,17 @@ class VARMAX(MLEModel):
             intercept = np.dot(self.exog[1:], exog_params)
             self.ssm[self._idx_state_intercept] = intercept.T
 
+            if self._final_exog is not None:
+                self.ssm['state_intercept', :self.k_endog, -1] = np.dot(
+                    self._final_exog, exog_params)
+
         # - Trend
         if self.k_trend > 0:
-            # If we didn't set the intercept above, zero it out so we can
+            # If we did not set the intercept above, zero it out so we can
             # just += later
             if not self.mle_regression:
                 zero = np.array(0, dtype=params.dtype)
-                self.ssm[self._idx_state_intercept] = zero
+                self.ssm['state_intercept', :] = zero
 
             trend_params = params[self._params_trend].reshape(
                 self.k_endog, self.k_trend).T
@@ -678,9 +732,13 @@ class VARMAX(MLEModel):
                 intercept = np.dot(self._trend_data[1:], trend_params)
             self.ssm[self._idx_state_intercept] += intercept.T
 
+            if self._final_trend is not None and not self._trend_is_const:
+                self.ssm['state_intercept', :self.k_endog, -1:] += np.dot(
+                    self._final_trend, trend_params).T
+
         # Need to set the last state intercept to np.nan (with appropriate
-        # dtype)
-        if self.mle_regression:
+        # dtype) if we don't have the final exog
+        if self.mle_regression and self._final_exog is None:
             nan = np.array(np.nan, dtype=params.dtype)
             self.ssm['state_intercept', :self.k_endog, -1] = nan
 
@@ -707,6 +765,63 @@ class VARMAX(MLEModel):
         if self.measurement_error:
             self.ssm[self._idx_obs_cov] = params[self._params_obs_cov]
 
+    @contextlib.contextmanager
+    def _set_final_exog(self, exog):
+        """
+        Set the final state intercept value using out-of-sample `exog` / trend
+
+        Parameters
+        ----------
+        exog : ndarray
+            Out-of-sample `exog` values, usually produced by
+            `_validate_out_of_sample_exog` to ensure the correct shape (this
+            method does not do any additional validation of its own).
+        out_of_sample : int
+            Number of out-of-sample periods.
+
+        Notes
+        -----
+        We need special handling for simulating or forecasting with `exog` or
+        trend, because if we had these then the last predicted_state has been
+        set to NaN since we did not have the appropriate `exog` to create it.
+        Since we handle trend in the same way as `exog`, we still have this
+        issue when only trend is used without `exog`.
+        """
+        cache_value = self._final_exog
+        if self.k_exog > 0:
+            if exog is not None:
+                exog = np.atleast_1d(exog)
+                if exog.ndim == 2:
+                    exog = exog[:1]
+                try:
+                    exog = np.reshape(exog[:1], (self.k_exog,))
+                except ValueError:
+                    raise ValueError('Provided exogenous values are not of the'
+                                     ' appropriate shape. Required %s, got %s.'
+                                     % (str((self.k_exog,)),
+                                        str(exog.shape)))
+            self._final_exog = exog
+        try:
+            yield
+        finally:
+            self._final_exog = cache_value
+
+    @Appender(MLEModel.simulate.__doc__)
+    def simulate(self, params, nsimulations, measurement_shocks=None,
+                 state_shocks=None, initial_state=None, anchor=None,
+                 repetitions=None, exog=None, extend_model=None,
+                 extend_kwargs=None, transformed=True, includes_fixed=False,
+                 **kwargs):
+        with self._set_final_exog(exog):
+            out = super(VARMAX, self).simulate(
+                params, nsimulations, measurement_shocks=measurement_shocks,
+                state_shocks=state_shocks, initial_state=initial_state,
+                anchor=anchor, repetitions=repetitions, exog=exog,
+                extend_model=extend_model, extend_kwargs=extend_kwargs,
+                transformed=transformed, includes_fixed=includes_fixed,
+                **kwargs)
+        return out
+
 
 class VARMAXResults(MLEResults):
     """
@@ -721,10 +836,10 @@ class VARMAXResults(MLEResults):
     ----------
     specification : dictionary
         Dictionary including all attributes from the VARMAX model instance.
-    coefficient_matrices_var : array
+    coefficient_matrices_var : ndarray
         Array containing autoregressive lag polynomial coefficient matrices,
         ordered from lowest degree to highest.
-    coefficient_matrices_vma : array
+    coefficient_matrices_vma : ndarray
         Array containing moving average lag polynomial coefficients,
         ordered from lowest degree to highest.
 
@@ -733,7 +848,7 @@ class VARMAXResults(MLEResults):
     statsmodels.tsa.statespace.kalman_filter.FilterResults
     statsmodels.tsa.statespace.mlemodel.MLEResults
     """
-    def __init__(self, model, params, filter_results, cov_type='opg',
+    def __init__(self, model, params, filter_results, cov_type=None,
                  cov_kwds=None, **kwargs):
         super(VARMAXResults, self).__init__(model, params, filter_results,
                                             cov_type, cov_kwds, **kwargs)
@@ -744,6 +859,7 @@ class VARMAXResults(MLEResults):
             'measurement_error': self.model.measurement_error,
             'enforce_stationarity': self.model.enforce_stationarity,
             'enforce_invertibility': self.model.enforce_invertibility,
+            'trend_offset': self.model.trend_offset,
 
             'order': self.model.order,
 
@@ -775,122 +891,181 @@ class VARMAXResults(MLEResults):
                 ma_params.reshape(k_endog * k_ma, k_endog).T
             ).reshape(k_endog, k_endog, k_ma).T
 
-    def get_prediction(self, start=None, end=None, dynamic=False, index=None,
-                       exog=None, **kwargs):
-        """
-        In-sample prediction and out-of-sample forecasting
+    def extend(self, endog, exog=None, **kwargs):
+        # If we have exog, then the last element of predicted_state and
+        # predicted_state_cov are nan (since they depend on the exog associated
+        # with the first out-of-sample point), so we need to compute them here
+        if exog is not None:
+            fcast = self.get_prediction(self.nobs, self.nobs, exog=exog[:1])
+            fcast_results = fcast.prediction_results
+            initial_state = fcast_results.predicted_state[..., 0]
+            initial_state_cov = fcast_results.predicted_state_cov[..., 0]
+        else:
+            initial_state = self.predicted_state[..., -1]
+            initial_state_cov = self.predicted_state_cov[..., -1]
 
-        Parameters
-        ----------
-        start : int, str, or datetime, optional
-            Zero-indexed observation number at which to start forecasting, ie.,
-            the first forecast is start. Can also be a date string to
-            parse or a datetime type. Default is the the zeroth observation.
-        end : int, str, or datetime, optional
-            Zero-indexed observation number at which to end forecasting, ie.,
-            the first forecast is start. Can also be a date string to
-            parse or a datetime type. However, if the dates index does not
-            have a fixed frequency, end must be an integer index if you
-            want out of sample prediction. Default is the last observation in
-            the sample.
-        exog : array_like, optional
-            If the model includes exogenous regressors, you must provide
-            exactly enough out-of-sample values for the exogenous variables if
-            end is beyond the last observation in the sample.
-        dynamic : boolean, int, str, or datetime, optional
-            Integer offset relative to `start` at which to begin dynamic
-            prediction. Can also be an absolute date string to parse or a
-            datetime type (these are not interpreted as offsets).
-            Prior to this observation, true endogenous values will be used for
-            prediction; starting with this observation and continuing through
-            the end of prediction, forecasted endogenous values will be used
-            instead.
-        kwargs
-            Additional arguments may required for forecasting beyond the end
-            of the sample. See `FilterResults.predict` for more details.
+        kwargs.setdefault('trend_offset', self.nobs + self.model.trend_offset)
+        mod = self.model.clone(endog, exog=exog, **kwargs)
 
-        Returns
-        -------
-        forecast : array
-            Array of out of sample forecasts.
-        """
-        if start is None:
-            start = self.model._index[0]
+        mod.ssm.initialization = Initialization(
+            mod.k_states, 'known', constant=initial_state,
+            stationary_cov=initial_state_cov)
 
-        # Handle end (e.g. date)
-        _start, _end, _out_of_sample, prediction_index = (
-            self.model._get_prediction_index(start, end, index, silent=True))
-
-        # Handle exogenous parameters
-        last_intercept = None
-        if _out_of_sample and (self.model.k_exog + self.model.k_trend > 0):
-            # Create a new faux VARMAX model for the extended dataset
-            nobs = self.model.data.orig_endog.shape[0] + _out_of_sample
-            endog = np.zeros((nobs, self.model.k_endog))
-
-            if self.model.k_exog > 0:
-                if exog is None:
-                    raise ValueError('Out-of-sample forecasting in a model'
-                                     ' with a regression component requires'
-                                     ' additional exogenous values via the'
-                                     ' `exog` argument.')
-                exog = np.array(exog)
-                required_exog_shape = (_out_of_sample, self.model.k_exog)
-                if not exog.shape == required_exog_shape:
-                    raise ValueError('Provided exogenous values are not of the'
-                                     ' appropriate shape. Required %s, got %s.'
-                                     % (str(required_exog_shape),
-                                        str(exog.shape)))
-                exog = np.c_[self.model.data.orig_exog.T, exog.T].T
-
-            # TODO replace with init_kwds or specification or similar
-            model = VARMAX(
-                endog,
-                exog=exog,
-                order=self.model.order,
-                trend=self.model.trend,
-                error_cov_type=self.model.error_cov_type,
-                measurement_error=self.model.measurement_error,
-                enforce_stationarity=self.model.enforce_stationarity,
-                enforce_invertibility=self.model.enforce_invertibility
-            )
-            model.update(self.params)
-            if model['state_intercept'].ndim > 1:
-                last_intercept = model['state_intercept', :, self.nobs - 1]
-            else:
-                last_intercept = model['state_intercept', :, 0]
-
-            # Set the kwargs with the update time-varying state space
-            # representation matrices
-            for name in self.filter_results.shapes.keys():
-                if name == 'obs':
-                    continue
-                mat = getattr(model.ssm, name)
-                if mat.shape[-1] > 1:
-                    if len(mat.shape) == 2:
-                        kwargs[name] = mat[:, -_out_of_sample:]
-                    else:
-                        kwargs[name] = mat[:, :, -_out_of_sample:]
-        elif self.model.k_exog == 0 and exog is not None:
-            warn('Exogenous array provided to predict, but additional data not'
-                 ' required. `exog` argument ignored.', ValueWarning)
-
-        # If we had exog, then the last predicted_state has been set to NaN
-        # since we didn't have the appropriate exog to create it. Then, if
-        # we are forecasting, we now have new exog that we need to put into
-        # the existing state_intercept array (and we will take it out, below)
-        if last_intercept is not None:
-            self.filter_results.state_intercept[:, -1] = last_intercept
-
-        res = super(VARMAXResults, self).get_prediction(
-            start=start, end=end, dynamic=dynamic, index=index, exog=exog,
-            **kwargs)
-
-        if last_intercept is not None:
-            self.filter_results.state_intercept[:, -1] = np.nan
+        if self.smoother_results is not None:
+            res = mod.smooth(self.params)
+        else:
+            res = mod.filter(self.params)
 
         return res
 
+    @contextlib.contextmanager
+    def _set_final_predicted_state(self, exog, out_of_sample):
+        """
+        Set the final predicted state value using out-of-sample `exog` / trend
+
+        Parameters
+        ----------
+        exog : ndarray
+            Out-of-sample `exog` values, usually produced by
+            `_validate_out_of_sample_exog` to ensure the correct shape (this
+            method does not do any additional validation of its own).
+        out_of_sample : int
+            Number of out-of-sample periods.
+
+        Notes
+        -----
+        We need special handling for forecasting with `exog`, because
+        if we had these then the last predicted_state has been set to NaN since
+        we did not have the appropriate `exog` to create it.
+        """
+        flag = out_of_sample and self.model.k_exog > 0
+
+        if flag:
+            tmp_endog = concat([
+                self.model.endog[-1:], np.zeros((1, self.model.k_endog))])
+            if self.model.k_exog > 0:
+                tmp_exog = concat([self.model.exog[-1:], exog[:1]])
+            else:
+                tmp_exog = None
+
+            tmp_trend_offset = self.model.trend_offset + self.nobs - 1
+            tmp_mod = self.model.clone(tmp_endog, exog=tmp_exog,
+                                       trend_offset=tmp_trend_offset)
+            constant = self.filter_results.predicted_state[:, -2]
+            stationary_cov = self.filter_results.predicted_state_cov[:, :, -2]
+            tmp_mod.ssm.initialize_known(constant=constant,
+                                         stationary_cov=stationary_cov)
+            tmp_res = tmp_mod.filter(self.params, transformed=True,
+                                     includes_fixed=True, return_ssm=True)
+
+            # Patch up `predicted_state`
+            self.filter_results.predicted_state[:, -1] = (
+                tmp_res.predicted_state[:, -2])
+        try:
+            yield
+        finally:
+            if flag:
+                self.filter_results.predicted_state[:, -1] = np.nan
+
+    @Appender(MLEResults.get_prediction.__doc__)
+    def get_prediction(self, start=None, end=None, dynamic=False, index=None,
+                       exog=None, **kwargs):
+        if start is None:
+            start = 0
+
+        # Handle end (e.g. date)
+        _start, _end, out_of_sample, _ = (
+            self.model._get_prediction_index(start, end, index, silent=True))
+
+        # Normalize `exog`
+        exog = self.model._validate_out_of_sample_exog(exog, out_of_sample)
+
+        # Handle trend offset for extended model
+        extend_kwargs = {}
+        if self.model.k_trend > 0:
+            extend_kwargs['trend_offset'] = (
+                self.model.trend_offset + self.nobs)
+
+        # Get the prediction
+        with self.model._set_final_exog(exog):
+            with self._set_final_predicted_state(exog, out_of_sample):
+                out = super(VARMAXResults, self).get_prediction(
+                    start=start, end=end, dynamic=dynamic, index=index,
+                    exog=exog, extend_kwargs=extend_kwargs, **kwargs)
+        return out
+
+    @Appender(MLEResults.simulate.__doc__)
+    def simulate(self, nsimulations, measurement_shocks=None,
+                 state_shocks=None, initial_state=None, anchor=None,
+                 repetitions=None, exog=None, extend_model=None,
+                 extend_kwargs=None, **kwargs):
+        if anchor is None or anchor == 'start':
+            iloc = 0
+        elif anchor == 'end':
+            iloc = self.nobs
+        else:
+            iloc, _, _ = self.model._get_index_loc(anchor)
+
+        if iloc < 0:
+            iloc = self.nobs + iloc
+        if iloc > self.nobs:
+            raise ValueError('Cannot anchor simulation after the estimated'
+                             ' sample.')
+
+        out_of_sample = max(iloc + nsimulations - self.nobs, 0)
+
+        # Normalize `exog`
+        exog = self.model._validate_out_of_sample_exog(exog, out_of_sample)
+
+        with self._set_final_predicted_state(exog, out_of_sample):
+            out = super(VARMAXResults, self).simulate(
+                nsimulations, measurement_shocks=measurement_shocks,
+                state_shocks=state_shocks, initial_state=initial_state,
+                anchor=anchor, repetitions=repetitions, exog=exog,
+                extend_model=extend_model, extend_kwargs=extend_kwargs,
+                **kwargs)
+
+        return out
+
+    def _news_previous_results(self, previous, start, end, periods):
+        # We need to figure out the out-of-sample exog, so that we can add back
+        # in the last exog, predicted state
+        exog = None
+        out_of_sample = self.nobs - previous.nobs
+        if self.model.k_exog > 0 and out_of_sample > 0:
+            exog = self.model.exog[-out_of_sample:]
+
+        # We also need to manually compute the `revised` results,
+        rev_endog = self.model.endog[:previous.nobs].copy()
+        rev_endog[previous.filter_results.missing.astype(bool).T] = np.nan
+        has_revisions = not np.allclose(rev_endog, previous.model.endog,
+                                        equal_nan=True)
+        revised_results = None
+        if has_revisions:
+            rev_exog = None
+            if self.model.exog is not None:
+                rev_exog = self.model.exog[:previous.nobs].copy()
+            rev_mod = previous.model.clone(rev_endog, exog=rev_exog)
+            revised = rev_mod.smooth(self.params)
+
+        # Compute the news
+        with contextlib.ExitStack() as stack:
+            stack.enter_context(previous.model._set_final_exog(exog))
+            stack.enter_context(previous._set_final_predicted_state(
+                exog, out_of_sample))
+
+            if has_revisions:
+                stack.enter_context(revised.model._set_final_exog(exog))
+                stack.enter_context(revised._set_final_predicted_state(
+                    exog, out_of_sample))
+                revised_results = revised.smoother_results
+
+            out = self.smoother_results.news(
+                previous.smoother_results, start=start, end=end,
+                revised=revised_results)
+        return out
+
+    @Appender(MLEResults.summary.__doc__)
     def summary(self, alpha=.05, start=None, separate_params=True):
         from statsmodels.iolib.summary import summary_params
 
@@ -928,11 +1103,15 @@ class VARMAXResults(MLEResults):
                        self.zvalues[mask], self.pvalues[mask],
                        self.conf_int(alpha)[mask])
 
-                param_names = [
-                    '.'.join(name.split('.')[:-1]) if strip_end else name
-                    for name in
-                    np.array(self.data.param_names)[mask].tolist()
-                ]
+                param_names = []
+                for name in np.array(self.data.param_names)[mask].tolist():
+                    if strip_end:
+                        param_name = '.'.join(name.split('.')[:-1])
+                    else:
+                        param_name = name
+                    if name in self.fixed_params:
+                        param_name = '%s (fixed)' % param_name
+                    param_names.append(param_name)
 
                 return summary_params(res, yname=None, xname=param_names,
                                       alpha=alpha, use_t=False, title=title)
@@ -984,7 +1163,10 @@ class VARMAXResults(MLEResults):
                 mask = np.concatenate(masks)
                 endog_masks.append(mask)
 
-                title = "Results for equation %s" % self.model.endog_names[i]
+                endog_names = self.model.endog_names
+                if not isinstance(endog_names, list):
+                    endog_names = [endog_names]
+                title = "Results for equation %s" % endog_names[i]
                 table = make_table(self, mask, title)
                 summary.tables.append(table)
 
@@ -1009,7 +1191,6 @@ class VARMAXResults(MLEResults):
                 summary.tables.append(table)
 
         return summary
-    summary.__doc__ = MLEResults.summary.__doc__
 
 
 class VARMAXResultsWrapper(MLEResultsWrapper):
